package ActiveDamping "Example exploring active damping of a motor"
  package Components "Components package for the Active Damping example model."
    extends Modelica.Icons.Package;

    model Engine "The mass of an engine displaced by a force."
      Modelica.Mechanics.Translational.Sources.Force f annotation(Placement(visible = true, transformation(origin = {-50.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Interfaces.Flange_b flange_b1 annotation(Placement(visible = true, transformation(origin = {148.4826, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {0.0, 110.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput a annotation(Placement(visible = true, transformation(origin = {-120.0, 0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0), iconTransformation(origin = {-120.0, 0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = -360)));
      Modelica.Mechanics.Translational.Components.Mass mass(stateSelect = StateSelect.always, m = engineMass) annotation(Placement(visible = true, transformation(origin = {25.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Interfaces.Flange_a flange_a1 annotation(Placement(visible = true, transformation(origin = {-148.4826, 50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {0.0, -110.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Modelica.SIunits.Mass engineMass = 170 "Mass of the sliding mass (mass.m)";
    equation
      connect(mass.flange_a, flange_a1) annotation(Line(visible = true, origin = {-35.871, 25}, points = {{50.871, -25}, {35.871, -25}, {35.871, 25}, {-112.612, 25}}, color = {0, 127, 0}));
      connect(mass.flange_b, flange_b1) annotation(Line(visible = true, origin = {91.741, 0}, points = {{-56.741, 0}, {56.741, 0}}, color = {0, 127, 0}));
      connect(f.flange, mass.flange_a) annotation(Line(visible = true, origin = {-12.5, 0}, points = {{-27.5, 0}, {27.5, 0}}, color = {0, 127, 0}));
      connect(f.f, a) annotation(Line(visible = true, origin = {-91, 0}, points = {{29, 0}, {-29, 0}}, color = {0, 36, 164}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Engine -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Active Damping: Engine</h1><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This class models the mass of an engine displaced by a force. It is used in the <a href=\"modelica://ActiveDamping.InteractiveActiveDampingModel\">example model</a>.
</p><p class=\"\">
View the <a href=\"modelica://ActiveDamping.Components.Engine#diagram\">model diagram</a> for this model.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Engine --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Bitmap(visible = true, fileName = "", imageSource = "iVBORw0KGgoAAAANSUhEUgAAAMgAAADICAYAAACtWK6eAAAKQWlDQ1BJQ0MgcHJvZmlsZQAA



eAGdlndUU9kWh8+9N73QEiIgJfQaegkg0jtIFQRRiUmAUAKGhCZ2RAVGFBEpVmRUwAFHhyJj



RRQLg4Ji1wnyEFDGwVFEReXdjGsJ7601896a/cdZ39nnt9fZZ+9917oAUPyCBMJ0WAGANKFY



FO7rwVwSE8vE9wIYEAEOWAHA4WZmBEf4RALU/L09mZmoSMaz9u4ugGS72yy/UCZz1v9/kSI3



QyQGAApF1TY8fiYX5QKUU7PFGTL/BMr0lSkyhjEyFqEJoqwi48SvbPan5iu7yZiXJuShGlnO



Gbw0noy7UN6aJeGjjAShXJgl4GejfAdlvVRJmgDl9yjT0/icTAAwFJlfzOcmoWyJMkUUGe6J



8gIACJTEObxyDov5OWieAHimZ+SKBIlJYqYR15hp5ejIZvrxs1P5YjErlMNN4Yh4TM/0tAyO



MBeAr2+WRQElWW2ZaJHtrRzt7VnW5mj5v9nfHn5T/T3IevtV8Sbsz55BjJ5Z32zsrC+9FgD2



JFqbHbO+lVUAtG0GQOXhrE/vIADyBQC03pzzHoZsXpLE4gwnC4vs7GxzAZ9rLivoN/ufgm/K



v4Y595nL7vtWO6YXP4EjSRUzZUXlpqemS0TMzAwOl89k/fcQ/+PAOWnNycMsnJ/AF/GF6FVR



6JQJhIlou4U8gViQLmQKhH/V4X8YNicHGX6daxRodV8AfYU5ULhJB8hvPQBDIwMkbj96An3r



WxAxCsi+vGitka9zjzJ6/uf6Hwtcim7hTEEiU+b2DI9kciWiLBmj34RswQISkAd0oAo0gS4w



AixgDRyAM3AD3iAAhIBIEAOWAy5IAmlABLJBPtgACkEx2AF2g2pwANSBetAEToI2cAZcBFfA



DXALDIBHQAqGwUswAd6BaQiC8BAVokGqkBakD5lC1hAbWgh5Q0FQOBQDxUOJkBCSQPnQJqgY



KoOqoUNQPfQjdBq6CF2D+qAH0CA0Bv0BfYQRmALTYQ3YALaA2bA7HAhHwsvgRHgVnAcXwNvh



SrgWPg63whfhG/AALIVfwpMIQMgIA9FGWAgb8URCkFgkAREha5EipAKpRZqQDqQbuY1IkXHk



AwaHoWGYGBbGGeOHWYzhYlZh1mJKMNWYY5hWTBfmNmYQM4H5gqVi1bGmWCesP3YJNhGbjS3E



VmCPYFuwl7ED2GHsOxwOx8AZ4hxwfrgYXDJuNa4Etw/XjLuA68MN4SbxeLwq3hTvgg/Bc/Bi



fCG+Cn8cfx7fjx/GvyeQCVoEa4IPIZYgJGwkVBAaCOcI/YQRwjRRgahPdCKGEHnEXGIpsY7Y



QbxJHCZOkxRJhiQXUiQpmbSBVElqIl0mPSa9IZPJOmRHchhZQF5PriSfIF8lD5I/UJQoJhRP



ShxFQtlOOUq5QHlAeUOlUg2obtRYqpi6nVpPvUR9Sn0vR5Mzl/OX48mtk6uRa5Xrl3slT5TX



l3eXXy6fJ18hf0r+pvy4AlHBQMFTgaOwVqFG4bTCPYVJRZqilWKIYppiiWKD4jXFUSW8koGS



txJPqUDpsNIlpSEaQtOledK4tE20Otpl2jAdRzek+9OT6cX0H+i99AllJWVb5SjlHOUa5bPK



UgbCMGD4M1IZpYyTjLuMj/M05rnP48/bNq9pXv+8KZX5Km4qfJUilWaVAZWPqkxVb9UU1Z2q



bapP1DBqJmphatlq+9Uuq43Pp893ns+dXzT/5PyH6rC6iXq4+mr1w+o96pMamhq+GhkaVRqX



NMY1GZpumsma5ZrnNMe0aFoLtQRa5VrntV4wlZnuzFRmJbOLOaGtru2nLdE+pN2rPa1jqLNY



Z6NOs84TXZIuWzdBt1y3U3dCT0svWC9fr1HvoT5Rn62fpL9Hv1t/ysDQINpgi0GbwaihiqG/



YZ5ho+FjI6qRq9Eqo1qjO8Y4Y7ZxivE+41smsImdSZJJjclNU9jU3lRgus+0zwxr5mgmNKs1



u8eisNxZWaxG1qA5wzzIfKN5m/krCz2LWIudFt0WXyztLFMt6ywfWSlZBVhttOqw+sPaxJpr



XWN9x4Zq42Ozzqbd5rWtqS3fdr/tfTuaXbDdFrtOu8/2DvYi+yb7MQc9h3iHvQ732HR2KLuE



fdUR6+jhuM7xjOMHJ3snsdNJp9+dWc4pzg3OowsMF/AX1C0YctFx4bgccpEuZC6MX3hwodRV



25XjWuv6zE3Xjed2xG3E3dg92f24+ysPSw+RR4vHlKeT5xrPC16Il69XkVevt5L3Yu9q76c+



Oj6JPo0+E752vqt9L/hh/QL9dvrd89fw5/rX+08EOASsCegKpARGBFYHPgsyCRIFdQTDwQHB



u4IfL9JfJFzUFgJC/EN2hTwJNQxdFfpzGC4sNKwm7Hm4VXh+eHcELWJFREPEu0iPyNLIR4uN



FksWd0bJR8VF1UdNRXtFl0VLl1gsWbPkRoxajCCmPRYfGxV7JHZyqffS3UuH4+ziCuPuLjNc



lrPs2nK15anLz66QX8FZcSoeGx8d3xD/iRPCqeVMrvRfuXflBNeTu4f7kufGK+eN8V34ZfyR



BJeEsoTRRJfEXYljSa5JFUnjAk9BteB1sl/ygeSplJCUoykzqdGpzWmEtPi000IlYYqwK10z



PSe9L8M0ozBDuspp1e5VE6JA0ZFMKHNZZruYjv5M9UiMJJslg1kLs2qy3mdHZZ/KUcwR5vTk



muRuyx3J88n7fjVmNXd1Z752/ob8wTXuaw6thdauXNu5Tnddwbrh9b7rj20gbUjZ8MtGy41l



G99uit7UUaBRsL5gaLPv5sZCuUJR4b0tzlsObMVsFWzt3WazrWrblyJe0fViy+KK4k8l3JLr



31l9V/ndzPaE7b2l9qX7d+B2CHfc3em681iZYlle2dCu4F2t5czyovK3u1fsvlZhW3FgD2mP



ZI+0MqiyvUqvakfVp+qk6oEaj5rmvep7t+2d2sfb17/fbX/TAY0DxQc+HhQcvH/I91BrrUFt



xWHc4azDz+ui6rq/Z39ff0TtSPGRz0eFR6XHwo911TvU1zeoN5Q2wo2SxrHjccdv/eD1Q3sT



q+lQM6O5+AQ4ITnx4sf4H++eDDzZeYp9qukn/Z/2ttBailqh1tzWibakNml7THvf6YDTnR3O



HS0/m/989Iz2mZqzymdLz5HOFZybOZ93fvJCxoXxi4kXhzpXdD66tOTSna6wrt7LgZevXvG5



cqnbvfv8VZerZ645XTt9nX297Yb9jdYeu56WX+x+aem172296XCz/ZbjrY6+BX3n+l37L972



un3ljv+dGwOLBvruLr57/17cPel93v3RB6kPXj/Mejj9aP1j7OOiJwpPKp6qP6391fjXZqm9



9Oyg12DPs4hnj4a4Qy//lfmvT8MFz6nPK0a0RupHrUfPjPmM3Xqx9MXwy4yX0+OFvyn+tveV



0auffnf7vWdiycTwa9HrmT9K3qi+OfrW9m3nZOjk03dp76anit6rvj/2gf2h+2P0x5Hp7E/4



T5WfjT93fAn88ngmbWbm3/eE8/vZ4MnAAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAA7E



AAAOxAGVKw4bAAAAB3RJTUUH2wsXCgkiBwZnAAAAIABJREFUeAHsvQewJdl533dOd98c3n05



p8lhZ3PCLjYgEwCJQBKySJoGbFoiXTZVsl2W5Con0XKVrZItuehyyWaZhkXLDBBAEAQILNIu



wibsLjbv7MxOeG/em5fjzaG7j3//u3PBIYSwABZ5zqv/674dTp/+zpfOd0Ibcy1do8A1Clyj



wDUKXKPANQpco8A1CrzOFLCvc34/a9mN8EIpsAVi0AEe8IG7ggzbUTAAsiAATVABG6AMdJ+u



F721r7yupZ8CClwTkH+7kkQTMfON4K0gBC+BFhCzJ4CEoQTSQAy/DXSucRUkOGOgD+g6nZPQ



SHj2QBVIgJSvkgTvmuB0SfGT8++agHzrushz+D1AwvB1ICERw4vZ26AOJEQSDv0WY0dA14mm



BaA8JDgSiCkg63IZyPpMAl0jgVkH54HyvJZ+wiggd+Ba+rcpINcqB6ThRSNZBzG7GFwCIGuw



D75VEuNPA1kNCcYukAUaBhKIVXAayGLMg4NA1+kZzwJZlmvpJ4QC0mY/70kMr3aGBEFMfDc4



BaTZJSRPXtmvsRXEwHKLxOCC7hd6+zq3BPqBLIWul7AIB4CsjSyNLJDaNrIeukeCdT0YBbpH



Qngt/ZgpoIr9eUp6XzGmhEFWQkw7DuQ6iUHFmM8DCYbaII+CBXB18vGdHBztOhIrnCwbG0um



yrcnLHK3bgeDQBZkCHwZSBCSQIIj5bQD6qBnjXSdrI+syjaQpVkD19KPiQI/jxZEwnAPkDaX



UKyCM+CcDUycDUyUi2xfLmf20zmTClr2YN4ECZuMi6mSCdsN06LR4eL/5j/0/tkXQ/us27JV



6yQc35zkjhXBUdCzQhIctVnE/ILKoga/BFWCIgGV5boEdO4GIKHbBNfSj4ECP08WRMrgPqDo



0wXwApCrg5of9LfN7viQ545Gxo1yMJfJpF5uhfFUoh2mYu6MEu65fMubio2fifpKX97Y3Vx9



3p2zbzr+Jrf18tLVdJSw6FmyBtcBtTv0LAmArutZGna7+9pKkCQ8cuF617DbdfnewFaC8zjQ



+WvpR0iBqyv2R/jYH9qjRshZkSdpZ7kzYsYMOA5+HYhxxazPgEXQLJrkRNuENwXGWy0al2+a



KFnuUiV7OWmi4WzQGvd8s7TXMo0RF8xG1h1qmSjoc+Zlc9L/3MUXI2l8JUvuFjbXMzxwBKg9



IeshQRwHcu0kCCtATK9rVcZeeFf3XZ10XNEvuXtzQC6Zyr4HFB27ln7IFPhZEhC5S38HyMd/



Cui3XJMhMAMUJXoYREjQHC+ehTNr/cYfbBm/ACduhEEnCDx3Q8KZ8UTeRC4wWb9tNgueeWCj



aQquY4LItw38oflcy0x7SffSpjNfq86kLgx7/Z0PvrIW/7NX2x3DPEd9IHqmmFlCIeamxdJN



+i1IOL459eqkd05bHZPwvwVI2JfAWSBFIGHT9lr6IVBAGuynPfUY6hZeRBpbjHfuykup8Stm



EmPKxSmhw6u5wIxmYjOYyNjVVJicdSbOdJLhgWTa3Z7LmqF8xmRSCVNIo+9TKSxQYA4VksYL



QpN3Tc8lXOHRRiZcTbbN0aRvJloJV8030rXNmolWTUdtDAnmAlD7ZheoHDouSyL0mJ7db5v0



Xr130/VyrxRAWADKQ27ZHDgM1J7SNdcEBSK8nulnQUB69JAbImsh4TgP5IooApTGb5lLGT8R



GOtZY4djz+U8Z6Ka8YZTcaaRLjZuygTmaJAxqXbbJLEUu9m0qWeSphJ4phVYE8TO9IeeSaQL



7mvVqp+NvGgiY1wm8kytU3bH29XW5pIJW8539St2ocfg32pLsbqpJwC939+87d2r471rZZEk



cHKxngKLQA39u8BFcK2dAhFerySf+Kc99fMCp668xGfYvqx9Oe4d4411TDzvGy+dMLQk8PuT



sasFbXdEAmPiKJlNVkeSWTO8VzMJIlQuapn62IhZGCyZdEwGxKeQJ+N3YpMKA5Pe75jbka2z



CB2WyraTztT6Yu/ovrW3xCaKOKq2j6AkppZm/3bpO53TPb3zPeHQVpCQyIrMXdn/HFu9n9pb



19LrSIGfNgvSYxSRQO7U9Vcg1+JrYPXZf/QX9sOPffRgbL07iyZxS5RNVFOhK9BTkYffRvGU



RujkqHVslKG1MpMouEO1uvHpy6C5YSwdGt5wxpS9wHRcxiQwO6mQljsuV4S7ZeK2yTkX9Xsd



04rCzHIQ2bEhk4obfjxSNzEi1nWp5M4p9crb27569Hv7r3slKD1h0VaNeQmh3lt0kJJQG+UC



0LN1zw/yTG6/lkSBn0YiqpNtHsidko//ApBbkRo32YmOCY/ERKMaKZdOx842fROUOjhIzh0u



xnJN/L4twqdRKvLp8UuVUiZR3TdD1jO+nzIbWI39gZypVtvmcJAw61NjZhNhMFEb20DrfmXb



FLaxNrDn86adWQwTrXqnGJ+f3E7+0rqJWlUTPU5ZLoIeo7L7DebWfi/1aN9j/KuPf6tjPL3b



juldp21PWE6w/z4g6/kgkOBcS68DBX6aLIg05B1gGig69BhYAHoHRaluatjo5rYXp5rGrvtB



OF6M3Gwhcvl8nCzVndfa88z4TuDP1D1XT6ddpj9nbC5t9lotU8BS7A72meV2x4w0YzNWKJqV



Zt2M27bZSPum5Utn+8Ztls3xSseU4O7HWnHmtLrzxveC24iCeZsGW/PXY7caFEw9iN/M7FzS



TT0B0Q9do99XH9NxJR0j+64bqZ55BQB6eapUOrdxZStBmQIngTofFYLuXcvutfS9UuCnQUDk



PrwBHABijqfAAhADHKdtcUfGeIf7TSqyNmwGzk3mjTc7GnkucESneMMtG0/tOpduOdcK6fX2



E7EtpWmt581uImP2FXcKAjOwUzFjtZaZabrg07mTuT+sLrVP5BCOamRmd+pmqt42KTz/vI1M



Y6ftbQ+5Tkims9bSAZ+J1lLWzDawQ6lEunIsDMvrXa/tu/Kn6kBQ9O1bCYiEQJnIlZoHeIjd



/hRF5iQcvXsusS8B1XXajgP1xYwBXaNjSrrnWnqNFPhJFhBpy5uB2hlr9ME9CZdcIhJFlNa7



hRq/wTO2QNN7IrAuhu+DrPFGU8YbTBsvUTHR9K7vgkpgMvg6ZRM7CddiYNx+IWVuxHLU8lmz



63yTa4emcXDe/Nkri9iD2Nw6ORl/cr3mzvp78YlMzgyEvslYa8rVqim5NoxmiWgZl0147lLT



msRQaINiNl60oZmshl4mtrbh2WinEtsGvP2dJETnVAeyitrn+m8wfI/xOdQ912tnLPBbTK97



loAYvidEarzLBVXfCG2u7vmLbKVcbgRyS5V0vZ7VS/p9LX0LCvwkCYgqSVpPlXgMXAdU4Q+D



y3BPge1NcM0hhOAg4doUwuIGvJj+OnMIbhgKje2nlZyse5FXhqdazlRdLAPSvf8S9z8lwRjI



mFuzKbOG1YjE9Nvb5vTzl4OHjRffOlwwIQKUdJV4PpMyRyJn9onlfjhv3X4zYuhHYLA/ppRO



mf1qyySCyNsh1pVNNv07C5FNbzvPpwxl8tpqxxZX0H07yyABEHReaQ6o7aDfVzOsrpHwyHIQ



Jug2yLV9GVSArtV5Jd37FqC+EfW7PAtocnXbarpeSR2NcsPkskroFA1Te+la+hYU+EkQEDGA



0i3gvUCVXKHn4mu/uju/sPwvdvqpwuvTLrgDfhp3aX8rZ+LZjHN9SEwh45Lj1HBU9WwOM1GA



Oesta5pwzCZsc9l39hyW5nycGzpvOlF+OB3dP9BnJjJZsxExCpfoVNpLmOTgWOxlPXNsMGsW



wrbJJDwzmiOa1eyYWqOTefDSVnhLX58pIjQYDlPGRdtq1e3uQCe5v5EIm/3GO520XnnHxKWW



jbnNrrnYScD1PnrH3nuy202939pKm4vJZ4GE5GrXSed1bgYoGCFG13VrV36z+UY6yd4/BLcC



KRlBlkRtNuXRE5rL7KujcQDIGs1f+b3PVgJzLV2hwE+CgKgo0oj/HpzwFNvPgtWEdWNn/vvt



O2EdBMOg1L1m3vj96chNjaCyGU+bahlX2va8/j2aFQ0T1dH223DBBqywyD0XwEU47WLse6um



VdvOpL07Csn4Hfm0WaC9MQKuR/2WEwmTCFvmumLClMPQ9BHzSge+acaxaZJnNpnuFLA2o6N5



0+7PmE3fmv0sA1oqTVPe8OzpkN6SauQueYmYJowrIZ0BsrdJyFi96GJKMbnw7ZKsQBWkgRhW



Wl9J90hYxOQ6NwcUzZLQiel1z9Xpb/NjDqhxrro9AOSivhlIeGQpdFz0XgWiURPomPK9Dhy8



8lvXSqiEn9v0I+8ohLPNK4zmPoISpK1A7aj+u0yxM2Xyz8B3Mxum+YZOOa7hykx5ocklYZ+8



DQcCZ4c6znr7LtlfYUpGzY9tHLhdE7o9Gs671KQYUtpRUR1pb2ncjkn8r/Th/a7J5iPHMHbr



0iYd1k1tcNQ8uLFiDk+OmnUmePiMY+9LJsw+TlFpr2kGKVlfX8rsdSLzC3QcLtOZmNqln3yo



j8a9ZwKGx2frObtuq8SVI/sfVZ0JPd89ShtkmNcsUJ4MRa+Js2lR00FPEsu77n/9+mbmW+bY



ISAXSPu6WklCpvQcmAViaml7pQmgdoeukTC8+oRX319CJGHQsXvAW4Do83HwGBC9JGxrQMUT



zZSGwTGg+y8BuXIS2m5lse2V65vLz6mfrSTN8SNLEg7aDub3zb/oPpOGbndLiHUGm5DpeOGB



lg1HOD7uezG8bBrJ2AynnDfiOa/AvIv+csJ29uIQhR83nOdtJjtuiQa6LMU5MpN78BLYBNKA



DC9ECtufjjO5Atai9Z/25816Zc9kamXvgTCReLbViE/1lUyyUzMlX/0k1qQSWAjfN5V2bIYQ



lvxIxryA21akDTJfr5sS50NcrUo9pHt+jc7EyA1lU94iAx3PtSMzBVEHnYanpMyiC4mSuf/C



xjsda85s2ZubA3bV1K9mrB5DI0tdBpRV0Hl1BOqc0HN7JAxyjfR7EUjBfRj8I/BbIAPEyDqv



utW9ctnUaNe+GFy47wqUl6yNhEb3KknQpFikZCSEB8AUGAV9QGXT+Z+L9CMVkH9s/vHfIKpv



vZFEyr0VhhtLMXiQoeQMf3IuZ/xs2pkRGH/Yg21axvbtGy9b8Vw59H36tWMxwTKXnmf+xjlq



fIHfYoKeLy+NpyR59KjSuJjsvD0Kzf0tBhQSvUpm8u7cxo6J0qn4Vtohfe2aae81zDAdhKN7



dXMg45sQCV2r1JgsQhHKDd8emvM+HDUZEt8wWcau7NacSYVVcx4LkR9Lue07xs3jizvmxhLD



4+HQqWRkp/I5E/5asbb19H/3dQahRO4gdvPSqwEkMWwv9fa1FXPLQkhgeoKk43q3LKDp1WVq



af+7wT8EsgIfBnpvteUwxF0mVl4SkEGAvulaiqUrxyQI7wC6XoKne18Eyqv3bAmgrMoloDKM



AAnKAaA8dY/y+ZlNP3wB+Xv3M9Vn4RsEHDFFO0qbGKbGhLsbrXHTycjUk7hOKefPZOm9oFF9



mIgUSt2lqoRUG9ZVsCo76MQdMlogZHuO7QVwiVpbA9J0YiC5CTNAFkQVKhZTZcc0sGfjyBxg



4KEdHjZrjaY5nk26w4xkjNq4V/t1M9KITdwh8sW4q4AI1XQmYfYQ0FbDmunQT3ztzEb+oVaj



+dsITrXZNtnVXTNUjs1Ozpmk1zK3rFfMbViheMv5W57zt/Gx/Drjvs58evPAdaavNpu6df+R



6EyP6bvF6/57taRXCtwtr47oOm2vnO0el1Dod09I/n32xeRfAr8DjgC5ZqKTGFh0kbYvAQmX



rIKYXnTSOVmpPBgDN4GDQHSVRRHzU01dS6ytrl0DErgUUD56noQlAUR/JV37M5N++AIi4Tg1



Y82G6gONa8K7cY/uho9m4Vy6JVyRPo5ZKM7oQT/BeKaRXRsmKoFjdIfp2NiuWS9YjTOJRe5/



Bb45y0wNMv2GC6CK61WKhEGaUu6VtKdSnPIMQ9rNP8gVTKa/z7xMu6bGixMQwxZFprhbpXMQ



V4oRvCsa1UgDfKPRMlk4MU6nTblFz3lfNornx5re3pY9hQTnak1zoNExdQTi6ZSPwHgmU8RW



pSNb2/HS20TG2nRcBozfesKPAwIJ8TvWo8WpTM5v3t+Z3j1HU8fcedx/73IIV1p73jra9N3G



CY/9huXovgD/dExJQiON3ms7iCZT4FmwCu4HTwGMWrddIkaXYEhA5LqJLspLAiJLoHM6LmHQ



/vXgdnAnkJVeAGL+d1zZ9pSQ2iaChE95SWBPgnEgnpLw6Fm9pGf23qF37Kdi+0MXENVUiHAE



qQQRVnM3gwWnvMCmbRAO2UR8KuGbPMM4dukzGN1iNh9hWtrEMEEMExCmhfMvxC5+hRDtBdh5



CeHYhtRXC0CP+NpKUFTZqiC5Ct2Ucf5kInC3U3W5sEN7o2WO0sFY5eI2veNFQk9jiZRZyebM



RTgQz6irfdu4UuuZtMkluNDGtJFqZgr3bJ1yVeGKHMy/5zUJIYc2XYiDR95zKvXA0+vuhrLr



HEoYV0gWzdPFZpCqR94gvYsXSjacdC4+dTGujSU8rzn0H7+//OTnH45u/MBv2BMvlvER6/hW



3WL33qn3Cr2tFIBSzw2SoDwE7gN/H8g107vPATGumFhtC1kTtTUkYMpb234g63ERiGbSYDon



N6sIxPQ69ybwX13Z3sRWwiZBkWDpHu2rPpSHBGbyCiQsA0B56txPZfqhC4jU+LE5k2pV4zf7



hGiTQTyayUXH/aQ5QWfbIJ0ZW0zxq+7HthmHXUKq8i6BV8ACUAWcBdKc2u8xvgh/ddJvQULS



u0Z5oQITac+P70khrUESrZ805xigmCNcm9UdnY7ZtggM+0MEDC7QP9KPZaEb0dQKOZjOmr5S



n1lNMj8Ei0JwgIgXQ+Hp7GjvFu2fp1qOkLC9/cJGOFbzTP9e0tqoE4ztNlN1F8eVABPS9jrI



jF3DnD2ZjKIJG8f3Jj7/VF9jfLjywuOPlCdGTrlqa9vbjwkH/DUjq/j6/c3p6mN6RwnDHLgV



yF0So8oC6NwIUDtBDN2jjZi/78oxCZEET+0WuaaiuxheNNRz3gtEd9F/CNwL3gpkbZS3BE/P



6lkT3atrdb+EcBQcABJSlUEW/6cm/dAFRJRAE9/O7LzZgP6F0Jm30s8ww0SkMo3jLRrFRyDl



1Eia2RmxebwVdTXQBW57GSwBEToFpC17GlQVdzWT9PbFENrvCgZbpUwyHX2QjsF7iUjtMefj



4aDP+1h1x71hcsJ06k2iUy2EwDewtSnRifiFfN48V62ZQxEOXqFg9vH1NASlUcYVIxRcYFJV



bnff3NVu+Lv50H61TU96LXbvSMRuMJ9LPLFTSDUJUhOR7hxO9IVH8imXKzZtPe9yy1sdP1tK



dlIEIdrQ4c7hqjlcou/xqbvSq/v91mRW9tET30i9d7n6/XRSv3vHtBVTHwV3ANFIzC96iQ7D



QG2PnnWRkEhAxLyroOeiioElCBISMfR94DDQ/bpG9SBLIIHYAbr+neB+cAiofaLnbAMJiyyZ



hEXl0L1y4Q5eQYatnqWyCD+x6UchIAfxnG5OGDsT5OPpprOj+02vQxf47li/2V3b60aOHL5/



IZcyQ3158wCN5gPOebg7NMxf1Y6qTO2L6Kp0occg7P6N1Duua8Qww1iFUwxdvwEh3UyG5kLQ



9suxF7+tjxG7SxtoRdoinGdso0ndMGkezCZMY3nX/EIU+YvpLNEDAgWUKZUbYHhJwyQY2pLq



S5uXEOjNQoPukzgeYG77Z6bT5uJOJ5qthladiVOFoDPfXzC5UtZkccfSrtDZrRP3bYWm0Int



Jkaq0WfbM8QJJu2lnUR9o7wXRoz2+mum6b2LtqorMZaSGE7vJ2EQg2l/FswDWRPRaQ6IIXW+



Z30lJLIU0vy6Tppfx6SA9PsS0Lm3gZuB6K775YpJbrUvSBD0W9ZH9+u57wNvADqmuloBem4R



6BoJi87p/ZTvETAB1MYReoLKbjfpnX/s6UchILf7Jj6RTbhDybQZhtmSRKEShYwGIBpbqZuJ



ZmjK9FoncWE8PzDlRpsBgk6pq+HEDAOgZ557jKFtL11NTO3rnN5NTFPFUiXoGZ9JWrPKWlcz



pZF4jn6XAtNsd9b3zCiRKlZr4Nm+WR3tMxfWdsyBLUWkrHkMyzNNm2Xcj4In77kt8wcvLZh8



tRW/EUtX3m372wx7WU47ly8wWDIOs6jRiKW0/PrcaDgzUXR9RLgqhLHlzBXanjmeT5qBfIsJ



W6Gd9Ex6qZyOF4uhvxjF7vpWFBEr6GpcMV/v/fQ+Ykox7u1A1kHvJoYWJCS6Vsz3HjAGpM3F



7F8Bc0DWRfdJi4thdY3ykLBImHT8MtA9U+A+IGvxP4EFcBxI4ytpK2ZXHirnAli9ghNsJVxi



fuV9EajsuvY00H36rbJKePRueq9xMApUzzqmuv6JSCLODzMdJHN409XpoS7gz29lifz0p0yD



UGoa4SgO95sFJoePIQzoatwsZ+ZGx8zHFpe7GuwG7hfBFZk6D56/ArkBVycxiAh7dRLBxUAD



jNZ9O+7VeDJjlvJD9Ea0zXDWN3v0kssVkDbbx3qUCKNdyqdMi4b7NJNnY/po2hQ+bsWmL0j4



S5/4fKLZtJ0qFmaHRrvxPFfppOJ8oWYOMDDyloQJt1Ipl/ISLWSdGYkB7R06FXHdmPnLOBks



E2qyVMmZnHrcN1z/hU4yF0TN5Zmi31wOY0LUr4aln6RMYqark9wiMaRcllNAzPwC0LsrieGl



naWNRfd1oGt7Lo+EQIwrZtY1ip/ITRLD6j4xrNwpHdPvl8BfgA+A3wfXgeuBmFc00/N0j3hI



Skx5LgNZOTH974I3gSfADpDQSbgeBBeB6lQWTOUqXfkt4dXzJWgV8ArQO/zYkl7yh5YYwHeM



t59l+upYKmP6cKH2GqGZg12atYZZLQ56n8OlmMj7JsucjP42Y5iwIDtYk3kYttDuBHfBhm9i



6BXdJV2i8bs7ZEIEFyElPCKqmKUnIB77YpohoMoaonE+D1NrnPw6IdxgZ5fjDAWeGTarZ5bN



TUStPPo/Uu2mmb28bRLlppmyjDZk1G8I+5RoL9VL/VF+INfMNyvR9YwEtuTjZdtuNazbVev8



Gh7ambyxyVoqOloqmBZDXwaTOVOfLJmlIDIV2hvcwXRGGvss/tBPCbfT+0zsCnfnrN861O9c



KsWErqr1fgUqTCUcTqCxYm4xq5I0shjxDBCTirF7Wljv+25wL5BgPA0kTLeCHh0usy8G1nnl



+wwQw0pJ6NzkFUj5LADR7jCYAS+CUyABRHtpepVH14ruUkQSij6guhDjq0wpIAHQVnV3O3gr



eAuQgOp+vYOeL6uie5SX3C3lfxIcAItA7/4jT6+7gAxA1wZ1M2Dyo850bvZ9d2sqZ06WSma3



VTeWuRVfDBhSvlP2amE0/JyXqN0PWViHzTg63xKEYTu5pHmIhn3M7KZfsb7r82kdYAFUEdIm



It5vAGmZPPg1IG23D3SNGEeElgCpIs/QPT+WDFjGkzkdaOmiTdEfwzJvQ3lzfmXHzDCLcBgR



LHKn7YQmCiMzSnslRAhCggozjJR8hhwHmXl4hPL5FYIK5QZC1U5/ruMiZME1jprCI5umeYiF



gQaYmdgeLJr1QpYgRNVMrO+b2d2GGcWF65D/ECHmsM7vFrapwaiZqdBmB2Yzj9tGJ7vf9u4I



fdvvuXgdoZqn/EtA7yxGkQWQ+yQlIOYW9K7S6L8NZAHEnGeBmErncle2K2wXgJhV5x8BukYM



KvotAF0j4TkDJJjvARISlUN0FUOL4SV0eo6EUAxdACpDHUgAda/OPQZUZ3cC3a99C3T/3eBv



AdWjrtdzJVwbQMKpd1Z+U0Dvq/fuJf3+kaTXXUAS9K+1eDeMwmHP6xxO5eIpxi1lBtJmtRaZ



7EbLPEaDN1PMuSNZv3aQ8Gq9lTJ/1K4z7ik2R2RBePMoSJkD7dBdH8UWBoEHY60X3SWaKuYY



UKVJq4jA+q1KlxbSdWIMWRZV3CjtjfelERLaALtYsIcmBr1Prm27W2ibNLFuQXmPoSMpc5ZR



vRcI7w7jXs3T37FN/0wMM1ug6q5mMoSDGWNFeyWxV7Yv1MzwJ22y0o+7+HaEI+8lnC0WzMDJ



Q2bhd3/VPPyVp8wJ2jL9TNGtMVV3gLW1Nmjcl5nSm6y1zWwibSqpur/DkPypuGWG88xYZCG6



I5Qzhcl8CLdTzCSheBP4HfAOcBuQ4IvhRAsxqI69D+h6MXkNiInE3KLJ80DMLYbLg88D0UvH



dP8CEHNKk4tBJZQXwA1gFvQB5SdhkkuVBmJ2CYForfNielkoCa1+q270PAnCKaDre3VYZX8R



6Pm3gl8Ad4ARIEHRs7XVeySB6nIUKF/l0QQ/kvS6C4iEg5Qi9j/d8UO5N9chIPX9GjPgIDG9



12PMpejjwWOQsBR1cDkq5nncmBManQiTlqnmHTroXmjUvL5OqFZAjD9K+OdVE68KV7kPAlW2



KugQELOcByKeNFICqFJOKzqG4B3FMjDe0X5xfcfmsEn30EivTA2apd2KGWVoyQwW7ABBhANo



/g0WjzuHtp/k6U3uGyFiRR+lcQxxnyXUm0hFjMGKm00iwSmf4/hPLAPhbN+IiT71z81nPvJJ



M/PcBXOIKb2VWtOP6zVvbZj5iJDAT9LOwSL2levmiGskLtZ9rTcXHymyCHDN2sFq4A5i0Z5A



BJ6j/PeASSANPQ7E9GIUMZ+2Yur3AmlpCccakBYXfcRUokdPaEQP0emvgCyuGFCMvArErFJO



YkxdA827jC1h1LEeg2qrZ+sa1YmERdcoL90v2ssCKH/VwRvBs0Bll7CpDHqm8pewqT7PAQnC



XUBKYAyo3BIiCZ3y0jOEaTADCkD3qgw/tKQCvp4pRWanwCEXtwsIREhF13BTklFgvsKQjAGG



ZhxiQlLMuSYdbnlWERljOPsvM7VhTry3AAAgAElEQVTVJ8r1ipbgoQ2Qb1ZNIWx7NdrtGcYa



9soogusZLwMxgRhERCuBfiDCqaIaQESVdsT4MGG9Y+Zxmy5mU+6N6X7XbjVNkzZJE8EMJsdZ



2X3XVChrCQF+mfFZW7Sm56xHp6A1C+MD5tGlTfNBRDRUtK2CD8m5LZsMh0sd27nVBR950cT3



oBZPdIrmrxL3mKW//Lvm3XCKJf+oE0cZP7Ajln4fOilVtgRKYh2r0lfpDv9yAdbps8Oh212m



AzJhvS/EbTeH6yZhEJP8ORCDfQjcD/Teej9ZDGlgMekgOA10TCkPxGRibh0TQ4tmEgbRqJd6



xNUxKZ5e0u9LQAwppr4IngBiYpVLtJa1EaPPAzFqFug+MfUZIGZ/DPxz8B8AWSCVVzTQ9UNA



9+uenoDKI3g3uBk8Az4OzoLHgd5jAkwB1fmbgOp4CVwGrSu/2bw+6WqC/CA5inHfA+7iDaRF



lgeMp4b2fV7STMBMG/XI/N+EU0/h0sziP2yo4Ut0KYd2zhf7u52EUzCymHmfMG8/bkw9jGJm



cMQl7mF+VNdSoIC7WkeVrEpTpWtfzCLi6Nk6JqLDn900zNyNX2cq7eLQAHPag+6AxRJc0SzT



9mDcvOvPEjDIwWEZGIgoEu0LdWRWca02qLmvbLbNbrNmfqeUMc8zYWqr1jHr5WZ6ccZGg9nY



Hd018SguUZqWeuLSsvnTD/8/weFaLX6z2imr215xr26zWJ+QgZLEgw2TWAiAoUVZCCJfbnof



6aRdHZMalOlxr0QuEycSZ71OtMYATTGQBH8RiOHEYAfBIfAkeBr8J+AWoDpIASkMaWNZnR7D



Kg/RSZpfDNujjYSjCGSFxaRK2tdx3ftOIAGRxlfe86B6BVR111J0lRD7qhvlJe0vvpIA3A6e



B3q+8j8PrgN6D1kAlVN1p2t1vxhfwrMAJAASFl2/BlS3uk7P133KTzygpGeKJqNA56QwdK3Q



Syrv95xeLwE5wpPfDh4Bj4IpAj3HCHGquONo3QwDBANin1MM68gyyC+Ln+/TCF5n4FWe6FVf



IuX9GYFRi1UpMYwjnp82n6SBq4GCt6A3YvxxvWwe6OVVwRmg8qsyBRFGWmgJqAJ0TGmQfogP



5GAfVlCsYakarYaxtdD01ztYliZWDgvHGrvVXfpEiK6VqKp9Oi7XyAFlzmLXjOile/swQnaJ



ByaYTLVdaPddmIzNODEFSeww7DPSSNtn6y1zeiLt3rFfNcdonK+3OwmGm7AwY+w9TaSOgb5u



psjaKLhsPpbIpnLuS9ms81jR8WTYMG/JeslL68WEH7bDbd5aTDECxNgSEDHTLLgN/Bl4GNwH



jgGK0WVkMbgYeRxIaYgRh4HOy6JcAqKP6CUhEM3EbEpi0h5Nb2X/N4DukWX6OhD99SwJoZj9



FXABPAdEd1moBSBBUT3p2J3gXUDPVLnEFVJgYmbVqd5JQjYIlL9+rwKV/Smg8um4yqjrVB4J



hgQpBXSdfgv6LfooLykXQceUp+jyPScR4/VIB8jkKPgqUEEnWWZkjBVDbqSHWkWbQBjGLWHc



/TI952jtRsPME9Vp0su9y2jaoRUT/Mt0O74+zeLRDP9o0mN9O0PSD2NlcLG6zC6N0g9EVBG/



V/F6Avq/e80q28tAlSFiKh2hHfGrtGm2aQcdwWLVaEPY4ZL5V+UKsV+PlUvyZnu7YgYpawch



buOODRCxGkvRaUl4eI75s9MqJ3l4zaZpMTR+zYa2zZKmtVZf+GDWukIjbw5nh4NPHCvdXl9r



Lr+bd1K7BQaPFqwXjbI00G4nss94gTs8jDvZYeQvk688W/Pq2Zo/OugSG3Dd6f2YlR7D6IAf



OsK83ZVYxBB67z4gRjkEROtPADHuJND7Ky0AMYfo8yx4BUxd+S3mfwGIaSRg/y54G7gJSNns



AzGhFIto+l6g68SIEgIxtZLyOQe2gei9ARbBGXARiGHPAj1/BRwGEvIbgOrsEpBw6pnKQ/Wk



PFXuFFi+8ltCVgWqd13TEwSVUcwuPlCZxW86J15WfhIolbkfKA/R5iRQ3irr95SkVV6PJELA



DF3iqhKHKK0YdYhXsQwQ3Edbt2G6Pnztp+ksjJmcVGAU7S6+uE8jfmAk3XkPPd1poldl2gc+



nYoPsiriLHmIMVTOfwUWwDvBQSBiy5IcAHq2CC+iqXJFcGkqEfIS1F3cbZkTmrqLkNI+NvV6



bC7t1Px3jBZC22y5Q8xFL9mkeQ4XL6aB/jXGWyk6dZB7luDUTJ7gAbMFC3QarjS9xKd41C0Z



v3Ndf8VrNZIs/OCZHfzBrfbQS0G0h3/OSio8+8vdMjhzzOJeOebGZ5LREsfmKRzjFU2mEtpW



JWbBYMLYbym5Vy6XzQlmEm9hMvXuykPWYxhcD94IJoC0twRHjKfrJBAvg1Ggd9c5MfRDQEzx



diCtfxSIeUVDMZ6OibZzQAz1DBCjjwE9S8Ii2ooRle9xIIaU4InWEgztrwMxs5gR8naZnE2X



/kfYKj8xbRaoDKo7MfMqUD6qY92rZ0kA9Fs81VOEOq767CXt935rKxoJSimgdxedlY9op+eK



fqLXV4H45jUlvfQPmlTAZfA0uI0M59lKG8zxCmrMXsQq/CmuVA20+rLma+MjZiWRZFGEhFmm



AZ9DU6+zosg8tVHERfFxeVQbHSJKIpYqW5rv6+Ai+FPwCFClidBc3b2mzFaVsAVEAJVLaSOM



gq80ml6eUO/pYeaTM1G8L2PNO6eHm/1Mky3T3nhyuOT9b5t1U+ATBo22732s1rQbCItCuiFR



sHKKwYxYhJh+kCU6B4c7XpRoBc6vOG9uN2HyFDRRqg1UvXYz75wdpp9vFVF9gojVKwhHEelg



0ZV0hGvJ+tmUCkGEM3I5G81PWzNJJ8ydT++aD6ad32kP5x4OPVbZerVyVUdrQBX8DjAHxDh3



gd8GNwIpBSmNQ0DvLtwE5sBpICHRU0+A28EMkPCJnqLjgSu4h+0xIKYSM/WeLSESk4umYmw9



X4LgA9F7AWwClVOQAAvnrvyeYjsJVI6XgOp0FtwHDgOVR2WYBiqjmFz5ZoHqVGXUO8lSSGiV



9D49qFyCyqtr9oAEVoL7IngAPAnmwAeAyv2a0mu+8DvkpoIpSSjiCVN4ET46zGJud3oJM8nn



Ac5vbQcfxcW4g76GYtKZc2MTZnGVDrp6jcUPWHYHrY6MmMR+0xzS4EXmiGzSkL2RxvoYQrXE



a+9BChFYxNPLS7uowqSdREwxiJ4vIekRCJ7tEsJlCJ0xFuwI/RARQ0z2aee0cd+OEeYV0avl



bf9PzmymGulkeHeauSa5wLu8vcc6EUnXT+iZ4tA6wiXgHq+1Yy/Syz3cZ+PzNwfZz2yG9lgn



H80T/Urk149/upbaG262OrfVm1afTMj4vj+DgZhDQOKUDUeZ4nuSNkhLwsZK8c24EbyYcNhO



1ntk7H3KuvDMZqX5JeN7x7str1cZRMwmZTALxDglcCu4Bei4aCJmFCOLDmJAMYuY/DkgTSrm



ywAdE2307n8MJIinwC5QPn8LKG/RV/wh+iqvCaBrZTEkIHJbbgPKT2WS4Oi64pXfYl7d/2tA



eUk4dG4O6Nli/A5QEg/pdxIoP72T8hKWQQVI8C4A5avre3zH7t9IOq77lCRMgu5R+aRoh4As



p3jo2+XBqVfT6ykgIiBzi2JWvXGn6EGvMjAwWWRdUPpEjsHoM0Rx/IkR88TBKbN05pK5q9Ox



yzSOi5Exc3DHaZgmwI1pIhzbc+PmI/j6KRrpLazQJazKU+Q/DvJAxBKTnALDQJpmFEg4BBFY



Go19WvieGSCK9H46/oq0MXbg+DqWYQ/N3iRgkBsZcau1Rvg2evCnGSay5zx3G+OwAobBz9HH



4SHEDcaNJepV8zJzQKo0+o8g6IcJ+hYvJzpzWMgJRu2uvThrHqUrPOX57V+AufdbHS/vosRw



zFAUeGG5Lx3fPFIyLE3Kc5smqFXs2f5O2lvKtjdyHXuRgY/t3UQcl//3G8+Zv1y7kfKLISX0



0qByQVShC0AMqWN1IOUgGjwKvgjmwTHAM7vM/TW2l4DyUx5VoHzFKJC+a5ln2IqJde0UuANI



qCRoEjqdF+0lGGeABOkE0DMOAJ3Tvu6RZdJ9SncDCZye9zJ4BOi5c0DvIuGV8L8ElO8S0HXK



X2kDiJHF3BeBjus+pd721V9/83/vnLaCBEZCImEpAZX3LOhdx+63Tq+3gGRy1l+h2THESKLb



0L6pwTwdbbE5oHVtiWptH5gyzzGCdnht27yTTupHmAKrNW8Hgn77e+V1O4vfP8XC0YyEMsVK



FYEJu1pImkXE04uKwDtAlSZNoCRNpGu0/UMwCe4CIsD1hIh/j/6MCQZMrpFBggiVmE4kYziL



8Vi95DbUZFAqml2GpNTL+6aEijsIRTs02BP03/UTVFjbqyRfZlGJIprAwmn7e567Y81j3FRs



B6OOa27ffPCBwc2qn7LNNzM7sUl4bMwL4xlK3bQJV+S7C+mJfiJiaJAaE+736vnP7xbi1eGG



OTTspS6v2eZURVG8v1qnu9GJ8cQcLSCrkAViEAm+BGT1CnSNmLMffBR8GRwEul8CJEH6LJi7



AjGr6l358ipdJtX+DUB5i2khR5eWi2xFVzEVpOsymWisZ4jGI0DPkGUQrXWdGFnHxJAfBLcB



lVdKDbJ2rZjyeAmI8XtCIEE5B1SGS2AB6B31zqqv00DPUNJW+b+W9M3XjnGT3n8B9PJj91sn



XfiDpt5DxKzDCAdj8eIjjNHIDZZcNmqYgAZwCgb16KkeZE53ZrNhJtGg0wO0Q+i8S9BjzbJX



ZgHxvomhHiWiTsuEg4uNuo0J5mQZj7WJBVkkfzGJBERMoYqWoMgECyqHKuxjQBV2CoiwOjbK



/fM0ihOM2K2Td4CQ7BG+9bEkEW2QNu2TcJfvELLu1RhDQTKUV4KdwcJMMW7qAu7fJ7GEnXzs



TSby8YOFKJVklOJJOLMQxXGLPILJeP/LrzSPVnLt1evoM0kRWm73F01lIO8SrNiYY9lTuoP4



RkJs8qycstFpJZ/LpulHj6KxXa99YJtBjQyFUb/ofZRZWvgCKABZiZuBEmTqnquyFfMIS0Au



yhPgLBDD3wSk8eWHfxWIoR4FYkQJj+hIcbo01PkjQPc+Bu4FyuMhoDzEyI9c2Q/YirkvAuUl



oZgBElIJwjCQMIjuHwI5oLrTu8yCOdATCtXfGfAiUH4SDuWhMisP1aveqw50bU9I2f2+kt7l



IBC95FJ+1+R/1yu++wViTKXjABff1lmVZBK3aD6Xjfthrj2q9wWWv4noQZ+oNbypZseN4k5Z



2gAaC19ijsQGXvh1MOZRDRZkyc8vlJjVVy57RRrxU9ZzLJ7YtRZ6OWkhVYYqQvt6WWkcVfY0



kICIoNp/BjzPMJNz+FnjWJIDRJvakFmDBgtYiz1CzTSTmMPE6Fu5dLiCjgBCi578cZjeYc12



UursathHOyzQRX/OIb9tJ1mtjmWI6MMxQV+WD0UzZKVq2uHG1uLqaSyn3MmDuI9lnicB1IAZ



MRy9hKa5UTfznQaLZ7eYDuNHBUb77rNeaYlue/ouu0pAzPUk0HuKrsfA/UCWROe0leAkgRSF



hEaMtALEwNLu2s6B58DHgRhV+UkIRB8JkK5R+lMwD+68gnG2LwHdcwhIQCVgyld5fA6I3nqe



BPUOoPeTBdD1umYZfAgoDzG9ygopu5ZObpiUl67Rc1SHykd56D10v87r3QbAAtDzv5/U40/d



OwzEQ1IUrylJIn/QpILLvN8NVgo2eZ4t7WC+R0aECpW5uVRO/gVTXdOjA+Z8IhfvIDwD6rCj



B72x22Z+BB12vH6LvoYLMNQiwzzu396X7+pgBCttI8KJUNJU0maj4EbwLqDnioGmgBhFzOMD



lUvbRjbPLMKE90XqeTNq2XMSGATBw1oco40zRFtE9sc16JdosA4WkaoJ2gkdRuXu0nN+zqv7



WEV7okF7JMq5j/uacs6clpLzW4Oht8AwyqG1fdbTqnQZTGricdpSEUoghWDTHGEgAOC5GuIy



2dkzkxaLuJ9st4s1O3+ibVeSxpYxHrdTkhPgKSDmmQN617eBWSBh0XvfDMSU94A3gF8ASqtA



TKB7ejSQJdK+tpeA6ucR8CWgN88A8cEa0DPuBbr/FqDn1IFoKhcsD5SPyiCGV900gDS/8pHC



0u/etXLv0uAgUH56vw6QMFSAyivh0T29pHoTlLSVcEpQlPRbZf5+k5TK1c/6rvmIcK9HOkIm



d4EX8Ie2mURxJEjErM9g+pk74Q30R/2su3mIzsIyVqMF810uMroXl+s4rswW81WXYczJPeZ8



M7xjZXjIfIWZSTsaGEiDmSWzrARolPyfBUtAhBZjHAVTkOx6utyOGcuIKt/fYvsGjh0GLApq



cvRSD+MGMbwkPoTaeyJIm03KMUnIuUOnZcBzxml8F7m+j6/cmkKexRq4hpmEFqv3wBbfLcz4



dnS0ZacOxKnGdmxObQTxNgMUF1iWSIv5JvgLWGwuYonS/YWl5HOf/Iuob20TSwFzYj18XDq3



WTHjm/vmYKtp/99S5K0OR8ENTLqib8U/sW7jfCXpXWTu42mTDJZwBicNK0kS4lNImsvsSuh5



RSYGFxmdHCDU/UDTBESXADwHxGxSFL8IJExizk8CMeM0EMPqmhToA9eDMvg/gI4VgZhWDKnz



JfA8eBzoWh2XwEjIxGzvAar3PJCArABZDAFSdxVXTzgluBKkl8Eu0LXKR4KpfMX4PbDb3Z9k



qzLrmUo63xOe7oHX8K93j8qhd1gAO+A1pddLQKRNjoHnmLkKz5sRavQ4ammQYeNletRPYk2S



GuJB8N9Hk/qscjiOVg2YH/Ll1l7w50EufqslusTrN7MMK6/VbBv/fxDdhkvkMbLVfY78pbFO



AlWerEmavpIsi0HsEVX6HBr9c1kmWvH7FKXYYRWRiyhurdpzN9f+EmAtN/tSI0qthGEEA5oq



U38Z6272EdoaAQMJxgLL+8hX/NQ2Q10Y6RvnYz6ZEAUsmp2M8fVOrvqdBfLcIvIEk8ZPV0rx



JT4RPUyIeBRhGN1biap/8Cfm6eWnTH1ng1A1iz7QMXpwl/Hx7bb9eCnOnNW0lwTSlUq4Jabv



jvChn9O1hPcS7xkRGpimkU4PvpukeAPHrPk3vx/P/y/rR//276eqX3+E+SsHmc9yNPKhTdxV



GP+adxMjvQt8CBwG0rxi/hfBOJgDYmpUQFeopGAmgATii2AOKMlyCbI2Eiwx/qfAM0D39IPL



QIx9B1BdQI4u48oSifl0jfhBvz8LVBbl9RRYAspbwqHn6LhSj5G1VZIgzAAJ0tUCxM/vKfXy



lRCfAiqD8ntN6fUUEBEqhfWAgW1/0booSppZywdsGLFboSf9ZZbM8bAQBYQjhXDwjSdTQ3D2



B0qmQhToCOHSFfpOInqxB2mgH6WRvMnnNdc1IAOGkVa6ExwEekFpqDxfgLpAR9sfrLuZ3/8H



ZuLpT5ht2t6uQZs5Qef0rRrwh8SKMBIsGMaeT0Zukr6JHdygLaJY07hZmgffpixlOiov72yZ



8nLZP0Vk97N+yDKlzpsu+dFT+15nr+bi9NaQ+3S2bmZ9j/bWoLeSqfkDYduuVvhgDyOBJy8s



mMNPfdkkrhszFSkF5oSMI2zpRmQ+blvjH8mYZmnP75xMYS2ThLH5TsM4y8jlo9Ax/tEdxEIc



40tZhzGd00j04snYfP2/drvnPvS7v+je3QmyjBz+u9Q6TSBznjJv816ijejyTjAI9oC07peA



aCVGE+OKWaSVJUiywkqPAAmRfqsOZWHkAul65aN7JBBngJ5xCIjBHwJ6tp4xdQUSCP3WPbcC



CZ+Sno/a6QqMfuu4LJ7ul3ApXe0+aT8N9F67QNco7+/FeqgMgpLu03srvwug90x2v3MKvvPp



13xWmugC3Rx8WcDvc3SINX3HZDmiWhqZa7w/299L/Xl+uPGbLoHQWHOWhinfuWESRWAmEl78



Lt5gXzP7+G7gF1KeOf3irvsgxxgoS3QjdqqwWVAEbbDPm8NftuLHbpe3zf5fdm3ktwbdZn4r



am6wSAJ9gizlyyLSCBV9GQSvzIuokI8e990XW3hCO7G5DqEtMQRlhI6b+7juIuTch5T3kr9q



Yy3VTuBh2dMtEx6tR/ZWvorD+Hh7MaiHO8xBv1ix8V3+vitOtpOsQOq1/TB+gv6S5/hmwvVf



fsi85REiZbRVPFy1JisKP5bvJGtVE4/tpjst+lLCdjM94k1aWvqNIb9ufzVGfbBqw1qzEbMg



d0ICSFwAabLpLdttKDFJ3A9/iyV+WcTRRPR/EghkgQuYm1A0uonoj2Jgr7pLj7N9ENwE5oA0



vupbVkDvKAHAgFv0kHsn738/v2VdpLElGGJMDnfbHBtsxfA6JsETs8uizAFZrseu7KfYSoh0



fgQUgPKTJZsGqrt5MAfErF8GOq/7dI+e10u6X2Xs9A5c2Vq2V1/3Taf/xk9dp+uVJNhL4Jvz



07lvm/xve+Z7OzHH5REmIZ3z4pttMp5jLfMXCNmO4KLP+AlX7S9Gaf1OWvM8YU4+IWi+UGmb



RSJYY7hdasBaIkk51qMaXN81J9VByNstQYqXwSvkL60jgklYNvD/d2g4H+HtadubFZYdufD2



4Xj/gT2vtGbdRIeFsNtwGTWyQtYeXz146XpciYdOmK/fV/d3H2wZVjvEdybUyywmDErXLVCF



iqi3etZ9IfDC9chFA4UgflztARbqbe9nCPbWosNo7tu48gM4REP7Jv4oC1NM98Wm0+54LzIm



OUxGfrUZJl7MutQTbYattNsRc9OZSOtVDx2keyffKl42ybDUyhWD/r5acWTApHP5xEq55XUa



rXgxsMkonXGjpaHOyOVMOFFu2cHAT94bRt4HrImWKCQGCa3ID9zMbSqyTUBAFkDM9gp0Eb3u



AbezPwLEIDcCMaqYUYzyBZaY2GKU2PtQJneQJ/LWdccm2c4DMfsyeBjMALlU0uwSCAmR3BZZ



F9WL7hkGLwG1M7Sv/CR0FwHV1A0vU+xvBAYG2P874JfAm4GeqbwkiDon905l1T2qF/TC95VE



k6PgPFB+rzmp0D9oKpIB9Df9SS8+mSkyM9A3Z/Z3g/W6i1gGirUFaTDTM51i8GG5tZ3+lxXb



/Ke4U3x41vTz1g6/vU1UaZp5H88wYvZhPrP8m1BEhFYlrwNVhgSjDi5hIEK+WNAum/Yv8lt5



5FBjBIdN/V0H3cYLXN+CUSgUK5laVZCGiniowZFXLtABaZnIi2bkHx+K7kY1Vvi9oBogSctc



oj3x8pB1Q7SPpyZCv33RD9M1S7ul2a08VdjbwAGA6+FeTJlgdNcVm32JnQHUpWYYnncBOiMb



7e6WURRhcqhk4uE8w1RSic7x5NB+0OnEfdlBd5rpxiOdqi34aVfmu0CUxXmJZNtm8/Fevp+o



s4374fBDO3vx+yzfiKCsvJ4VPdY6fLQUk1GCfVig0jJjl+H7rzLzSc5LCFQ/e9yjdgGBNVo4



uKDsvwgWx5h2AMesdgIzj7uJjHWvF3OK1mJ+af33gdvBYbAJdO80UD6qHwmmlIvoomO69xkg



Bpe10u8vADG+BE3Hx4GuEfOOgVlwBCgfWRa9n9xDHddWVkzMzat8wypQ3O+adI1cQLV19Pzv



Kf3AApIzQYb1ZFMQna4F25cPXP3QpDn9VGQGOvsMEYERsQZphomnfeZj22LnXkbzVmkE38Mg



wJilcZqEdQe42bA4Z7FaNreGMaFdVh6Ez0QY+K1r5kUYlD6z8hjPyEd22mIImGmEtgbfQfBz



bzycuGXXC4/sO3eKqFXK+HGD4eU+Wp714vgQJ/0WfBoqeWvmTbWR6NH2esgEwYjeBzQ+8YLn



qIe70cSpjEn8UdYL83xe/ci0DVaZFvkWFr1qoDqH2i7+Rd6TCqZXhanBlIfB+3CAH/Llztq9



HRfn6CfZqkV+K9HwlhebXinLiF2aVkfxKfCOgsoGC1n090UTzGg8G7ZpbYRhkMhLaKNLYcNe



RG4P+EF0gUDDINahj+H5Ed80mXItn3hHgiBaw/Np47EU5NJoHHx1x4QHmXp5EwuJDaI8tHap



aKV/l1G5eJNuisKqv6fOMeIZDKdBYHiJ1m8nky/9cdRMXoqwLlqzzJkNvLkkkqK2CDQxc+Au



oCRFJZfoBBAj6/0lHLIsh4DcrQfABBDjLwIJzHXgc+AT4K3gA2AYSHh1jOJ0h6So/SRLJG2P



LHcFSIyt8zouBle59JtX+a5J1ylJKFV2Cfv3lOCH7zP9CvedFnWSRRTP9fjgMG/y+pMHw+qR



aXPpyfPx7djXZRrlaWpmmEiNhnfnGDQ4Sx9IzLATxjNSYM4Taj2Ii/MwbPcCTvqNnbbVi6hS



9GIiopKsiRJaEGeNBAUP8QKniJHMV7LuRG0oPtkuxLcGGXMwopFbi/nkAS12qBQyZL1VdN7y



B9OTLw9+/P31Z7762OClth3eY+w6Rq6P6rwEh2b4UM9i3iRwYeKjfbSF6D9hrV436XksnE1f



DZFfxo75ZaJXKToZeZQ5C1cyQsbdgI64C4f+fZQr0/CjTNVF9/Ktn1+KXXhPKxEObvrxEG2z



w9kSKzHmEfTALDJzarfT9G6PiLWtbrvVcjk8i785k0rFfYNpl6DDdO/CZVsgBH4SzqaSHR5q



HDOebBcB22Sq4iYEegU6rMGJ3a9iwTkUgdHQCAT9K2vERi7iAlqINoSTwsL53QGYQ3DwdjwY



tl5pm/cjhDdy/Rbj1RxCyet06SbXTNpX2lyMehZ8HtwMZJnL4D3gzUDn18Er4G5wA0gAMfIQ



OA+eAB0gayQBEgOrrDqv36NAVmIbyOJJuHS9rtF5WUU9Awv6mpPumwayfDuv+a4rF37/AoJw



KNFBcNCnlrEkA4lkfPLg9fHzT5zz5i6v23lGwz6UpCGOIByDWZusZrKrBgMz6YZSSXMRlyqD



cByHSi8jQHu7tD2IcC3A0ftFJI4AACAASURBVBIKEVmmVz6vtI22MvkiWB78t+D9hKzS9F0E



WVy7VNatFRPugVbTTdEqnyFK1ddoWYZM2QqMgi0x4R/H5cP/9F8/9M6vb7XeS6/hvfT5jYex



Z710tE/nwvOd0FtqpOMVwmyjxcg/sWbC8ZKNXxqICdk6O8bDGc0eN+ibkLp+4H2R+cNZ8qdN



kuXL7HSnuA4zqZJx4BOyZXiLc4ewdJdHPPuRcd/8RTFMrufTNp1Ix7lqx1aQMJ822LFaJdVp



tqK+KKIFx+RcYsCzAwU3xSDOaHXTDmmSF9+KYElTcja2DDE2Ch5Rv5j5KPouIgtvQ0dklmVP



X7Ui6h1kFrBfHjT+2XHjHieUvEn5D6OMFLyQi3nznmdu3m+YaRTWBgKSh2VZapjPTiAAWKMc



7TzI3G0PisHWwHEwB1Qn2i8BCZAY9xHwJvDrYACIMcWgF4Aszxx4A5C1oQjdDkxZBXRp1w0b



ubKv/CQg8iBeBhIaJQmGyqHjKpjw3dI4F4ifnvluF36r89+/gCi3PAPYafilYm+RwVbXpTPt



wYV1+9LyuncTzLHDDFo/xfcDGSRYxMctoZ2iFM46gxCTDPPQKunzmAq66sxXmTxVbTb9ywiH



/FyZZGkT5S/tIa01BSQYIvT14L8EAwzjaCJsHQ0Z6evHpYu9dTyuET6rFu1XGDLSTj5DIz3L



dUe9rLs5N+JKw9N2ncGE5UzJlVi47kit4efaceKVIn0nDMIacHGYKQylHoub8UCLpYJ+NeM9



RiN5ZA8XEv+Fz6Kb61Cfe9TmS58ZSn3tl+8I1j+3EvWx2G4OM5rCUs6jrs/DaES6vXjA+F/5



vTj7sf8zap99e87LrhLmPr+SntluJh5u8uEQght+X9b7E7PpFlniFFlsDxYKLj81aZbarOW1



vGIPMyq4lgpirfTY9FjXl+cvQYxyx3lJBGSA5x6EX2j+MRiGAZUwO3Jq9/l2/Eoe5s8m4iq+



0A7ml3GXTExTgxdrgY4vtlpeI+MRnXOOcZt2iHuRF1sW97FP+8VuUgk38fMEx/phGowQzM3n



6jgnS4WLap/mtyzGvwNYhrvLzBISWRqtok/5usJziq3aJKpXMS6GzXwF6N4TQMeVJAyqbwnl



K0DXSkFS/G6iGF0B6QmJtlfj1ate5aMD/FgEUq5KvXte/fUd/ush339qh3mafFq1nehkfMT3



XGa/5l9yEd8YZL4E4yswnUwUoheYr9ZKKDQGK0tbgE+E8N0NprHy9aanmb+dadS9W6nYr4I7



KNAsECFUPhHuqSuQYyff9xgQMWkIEMVKojkJAMQdFtnJMObLBWMsPDcXtt02vfVfZ/LqBOOi



Zpm5uMYn1L20l9ntuGQY1sxxogN+rW3X/Mh7ImvD2gi99iw0f92RMM63Em70QCb50P9XDs/f



QZfLMp9QbxLNosU/xzvxVV2/XKvnzt+3kNn/RBQPbfL9jyZfxdKMXlQwcun47oILAhtX+l12



8fHCndufqq4MLbbbwzumU6p3ws8Frah1WzV+6KHd8FP/o8vuXjSdPH2Tpe2Gv7O4ZZ7d2HIF



LNzRwQHfYokC+luW0i6+XDTeVqC1TQ3fbkRTo2iYxRnw8UMLI9ksbZR9Ou93siZeyhmvEsV8



1SeOJ7h2DqvSIPpcaTg3TRybNpdb4AOpNAG9bWTmAhLms9qkNK8CAsgoY8vQ4rhebSSHwCMW



RsJA+4iGXqM/cI92rDfPNOujnOcbYQCLwj5fzuNb9RJEa0fxJTBI3fYlj+hGtdQukOv1NnAj



oHhdAcFAdj0GWScJk6zNEJDClMCJwcUfOt4Du98ySeAOglvBKJClk/C9poTw/0BJzDsmwqJO



VihpHt+4AfEsZlwElv8f80UavgplLjPGaZvRs88VS+YM7ZIzjGh9dHvD1Js1jyEhCUwpOvfV



+QkfZfuX4NNAhNCLbQCUYNccL7D9n8ESq8ATPrYJeqtLUeTlomZqq1NPNOlDCLMFZgTyMY4o



Tn+BGvoK6jGhldU1q497Gx7+FasmLme9+Km8CVuWVhHSPAAHPL4VBidoQA+fK7fuKVrv7/1l



svqf7WWj9xN7lnUTH9AN4bKXmVZvzWZ7lEVKKD1+OOOSX/Wh9QxVpiIN+WUGCJjyg22Wd9yC



aA2kZ5trt+DAg0Qdxp1/PNmwLYpHixkXiYmMJZb+KbQa/hgWo1HMtNOjE3S5BkEf3EHbAjoT



LGvTEUo5xjjWZO570k92pjw6MCnePky6wbP26W73ygg33DdDWWgzxkQAo3k4pwQDLFGOLhMS



7eZ77+4l1O0fDTj7aZ5Be8fMIixq2HtY1zNpZ8+jhrPqW0rFLH1kIW/CHOH7K0zNN3lowE/z



Avky+csU+B3Q/uMr3Y4PILlVwjI9pay6liCIRhIEMbIYV3TbAZeBBEb0lKum82rzSDgw3t16



UF0IM0D5Kk+dV9K+koTw34AHgZ7za2AWvKYEDX+gJJNF0yKeIKNJxl7hn1vcJKdoyWHOvUQl



ot28kLZFk+mnn2Hljol21ePzGS5BNCjBF5dWIO6E77fSXJPEPZHJXQQilohHR3nX372TN5YG



wZvojsbUPn4wk5I0GoSAbYKvnWeLHVaTtperu/EUcy7GiWB9CCu+0opRwAxzYQjMcJqx6vl+



v1Lbc1vrW2YyTFFxxeiJVs3jC1iGpa1MDfMXVxPuLZMj5ngxiPdYgX6aDszi7qbLM2QEl9/6



xB1ST5jOBOYs81HbeQPtj5vwNYqc0/urfKpsBMkklm009Jnrs6WP+e1pTh7DBYM0ViHZA6j9



HT4zGv/9yaHNj65s7BFM2Kh5cYoPiLDsanx8aNB5qOpLzFH0xubaextLJnOJoSusqIeg+jAP



I8FgplQhPpLNshhElf6Vil2gEbHKAGRWNiI6SGQJqzYC49ZYRWYAv2gMJl+BidUG4HZTT/tu



C8e/OsBgF8LoXz/XjU6G11PJyCwv4bxWvwm+jIDxma/OveQ7a2O/3GhF1+Pq4X3SenJmTdFF



TMVllh6Y4FlHeCZ0sGrX8Ei3BT3E8MhRtz1xB1sJgupd7Q7RTee4rWs9tL8PvgZ0jZL4Ig9U



biED1IDvCZ/48hKQ4Ot+8dIFcBn8Guhdx+53Tq/5wm+TDe+sJX48TUQiHu+mC7Pxk9mcK2Ri



c3shYNwfnV18GGCYtaQuIUArpY6/whijMVyRWpLlcCC2VnbX0kDbVxrn7ybPGSpkCkKPThh7



nuUOX8aFOoQ2mqLAN+Mn77mEv2ySiRxOFqsmxn2M+dqHiUuVneBC1E5tsEr2Xa2OW4zbdhHl



4+Nm6fMGSdorxWolDBj60djbS460Gh3CWOaz+IjtyPdXWHe0b7NjD5djN0c74DBWiO+rmydp



9K9jpcaYXxV3Yn9JYxMZ3Xug3Rf/clyyR1yfPWbT7kZGI0+HHk1r3213g9TOK3leUGxn3fFP



1tpv3SjYO5OD3pvhFty95MtBFN1F4Xb+MrG8+8BodoBl42+oGf9w1dk817SHiv782AA2MjBb



zI2p1CqJ9YGJ1JCfDe7nWxFjRNP6GloeiJAwY9gKuZKpF4ZZU7iZi2w7s5nO2GTb9weJIszj



6ehbJwmGJh/AbesgEExl9vdxjaOk5zZG4mA5Fwf7cGPmsokOsDzyJJaO4IUJk7hLaLPFgoku



z3tuAcE7zRp3KZTjcbgvov2SRoFsEjRZpY6kZC5PGv9LPFMWZxoupmtJC2fKR/ZgVlfC0xhC



wjHktFmQdq5Z4bSshxhclkOMrUb5U0BCMgZOAV0nayIBELQvS6F714CuPQDmgNpB1GJXqG5j



K2F8Erym9INaEGnzy/SBqEOtzKqB1cOjfL6gZLaee5ZVNGmo486kwyZRCBgCWYcX+WJtwuEO



m9Em4Up0gqIhOidXSi8/qS2Rpz3Ck0/wMZHzSesajEmiU4yh6MaeQhh/03biDA3sm1m56hiZ



XnY44wxyydDjcTlXKJ1bu9SusXTJV4ncLuIG5FzYovvE3I9m62fp21axP3o+k+lUzpzGJ+cj



BRTiDhYneaxt6wubHgu9MUU42yFYzLJDLBp3YIexVAyNGSTAvEBAgbW8wvECn+Qt8UX0Qp+p



Xl5lxC7rXdH6rVe3ceycR39F6wA13Z/w4K8kJXRmgUKcre7bN/DqC14iLtJg6it77p6Xc2bu



ud2NLIHvNzRjnwUb+dxbKvXn6Wy90ajSb5h3Xrtj1/qG/K3yTjCbztRNbiBK7uybnVY9HY8P



tQuMGG73D7nq5rrdHZmPnt3bbR9Y34tL7VY82MEiuThBH0cnASWSaPEKUayhpGebQZw8m0u0



Nxibv88iXsEuQ3HgugO4pWLqGMVE1ZoF1PYGnUnVXS/O78VumNC+YyjC03QIF1FmWslmnU93



y4rsl4y/PWESDdaXff5F02nRsfU+6nWMuvPo1Xyin1ENjD+7p0Y4WM9AOvhAVzdaJS0vhhc/



iOlxvbvHMdRdSyGhEciq63bJ4syCLSABEU/LomyDBaC8ZF3eCnTNY+A1px/UguhBBKfMdWkT



rFDqg0NJN/Wfv908+qUXzYGqPo6DaOCDLdIfsQKDjeDPzsGhi1Hon2pZW8Udu0geEjSUTneg



nV6yyZguQsc+5t916L2qFhG2lvGIGvtZvJMBTPURQqh3EY5tD0XmUUItQ9VWNtOsB8/VGtF+



rRneyzUjNGuxUNFNRPdvQZtt9peCuFAsMYW28KdbK3sN27QMAckwJCzKTrBCYjUV/iJrkCwy



jmMB8t9Lf4VjCPsLFcZTIfD0apvRyVEz2ezEjShkpV9cc765vowLsQSzJSBGrlK3Q7iVLXjl



FawifaJeqMWzsURLuT5vjQlZM4wY+MTWjmPcWvwBXM+JZBF/JuktMDQ5Tbja0t293GhYVlSx



uSStnDIfP/RS3jMbG50bUl5zjrBcmW/W9S2uBeusCpwa6ouyo2OutrHGqiwtb7kdhilWxZ8r



5KMhP+MGKi1vvRWm+RQkH/aN3XQm7fqmh81+vkAQrW5W+kLvHA5yc49gICr2KOpbs0M1nKUP



rb+KcKwMmGAtw5SxXT8e2IvNSVzKYa4jDqK2IZYGAcPXq+H7rBSNv0r/ZueyDccrrFGgZinW



aIMFBU8PBW7xMC7QvPNeRBoKCCtRaEYbvCoIC9S/rIf4QpYiDZChLtOL+XtWBYPTbXyPs1Xb



QpZGfDQP7gMSEv2WBZHifQZ8FSCTrz29HgIi89mPNWgzenuc0ahHiOvXmWPhn73sv3u/nTgK



Z12HL/VGCMn3zs0FQp8QkzXYLD3wSWZndOPimhzV9SulMdaJes0ziJHxi46xf6bJkr0DO1iP



kO9v4CawVKGdYWEIPx2b5yUwuDuHqcxzcRyu4O5u0kk+QxTtIIQ/TORkWlEUQl4FOrwXSunW



k/Vyc3t9113CEeG7NmYQQjzEKtTDlYH4XazNZQt1rJ+PC4VA1MreAnMCH2yE8ZG3vcXE/8M/



cZcvLfovXjyP65F0EwhNSO2v4SpkCWFPV+uu0WnTk2/cC7xLkmE2O+SfN1w0MGLXq+VOOqy6



B3bqFi/EnOILu2rYVlgZ/iJLteYJSY9V95OvNDvRSK0RjxQG49Vc1p7lU6EeHz2dxI1hprwb



2Kt6W3vVxNfzqc42bZRsvZWopAv+CnK6i9c0MZhL8o0Vf5K6uLi7Fz9OW41JmzFRBXtyeiCI



J8YSm3Vm3dMmCpKlRCfrpz2izhORlzyAK8qX5VhSoK8zkXT++UKUO8vSRLWmi/ObsT3AwK9Z



6M5ws0Q6mSbUnqZNE/uVHO7XYOCtYI1q+yYqbBPUQLHNoPBZcziuD1r73LRLbbadF9DzOk1U



YwT+0VAgZhx3BeM0NFsFyE7X1VLUSVCStwFdu+2KUbYSmCNAwrEAjgP9fgKovTICZsESeA5I



0ITXnF4PAeHluwV/ntJOw7xmvWZuY2XBgf2ql6GUWOdYzC/QZuP7IEQ2aPXt0kAcYAWDKY4x



V48bXzWxaowpRHiQV8lgeTxGxJ4KM24ul3fVwUFWOywY124Tp237DFg0GCVWgCbSRX8lI0zc



XqfjtAqKLJKIKOLJJ8X/Rd+H3oX6frhQa0YeHzK/FNKJQyGZd+EXlp1HGDSapbPjWb49uLRl



3Q3EXB6PrD23up3e+f+Zew8ov7L7vu++f51eMJgZdAw6sNhdLMDtSy53l0UsYhEtkbYiW5IZ



x7Ip6djnODnH8bET2TlWnONER4oTxyeWLCmSqGaKkii2XXG5u9zObdhFL9MwmN7Lf/7tvXw+



b/AHIUbySZwFwAt8573/K/fd+2u3/259vbrlCz8TKg88GlrfOJOc/M7L+fn2lvoR3Be14Yb3



11lAvw0lfG55NfNtSrcH+aaNyWnaJQXcAiEzme4VhthXV+ory4uZZ+ldOhFlMytYcyY5h04m



as6ssSEDpSqlb7JIDY8BvSS3tMS8sN5wkfMj1VKmI4cvX0zD0vRsfqhcSS7Ss3G6py9ZXill



2qrl3GKUq3Yzg6GfLtxtSVScmpgtf9ceRAgsLfId7dG9m7qi2VI1G7EByniho+lSLa7viZrX



TzCgu2u93Bxls9Vs745KU08fSxXWkqSlrXqViZvZObaOQ6gPUq3GnwVLu3LFXFtzvKO7q560



dcXV8mLz5c7QOpZpLTXj0/gQVTUGgqkwh9x6a5R5p79QHyvUcrVJqnGTIT6Oid+OjKzAZ2b2



pF2+KoYCbRWKT6QdNtTI0tICUUmrVYMcrTrZq2kbxI6GdnAfsJSw5JkCKtplYHz/WeHdUBBK



1HRM4lmK0F116gzM0l0slTIjeEh7qSmK36YEYKJrqs0tKNE5igwXLlX72YAWCnQy1WOCuRP0



sFJHTBKLwtfo09+KoBzBiu9gn8DNfd3htPM5aMwVe3uxOCzAKi3ToUkJg3CVsfStfEOloKBK



Vx6at/cAi9R0lJhqG+vL2Q8qEzfz3TJdtvV8Njt2b739talQOcycpnthSbm9Ep2n8ntwiY10



ytXcCwzhLGU7C4PY3/unJuNPPvn1EH31qbC5tBrt6M3mXu9sDldy1fbvXp2p41Y1Plljsj2d



B8f5o7Wbpj3T19Ec9Xf1Ikh90cvzM/GXlhxRKCQDdKsttxYTls+gpB3UuelLaMolvUgLvUMK



dQYytPzGzEyGPd6TT2/qzdRmpvJTV8e6zhbbkum4vjZUqm29sFxbn+/pqm/q6sx0UnrS75V0



sOPuWmk9GZtfyVGlRSZTWmR+pKMl39TUFpfn12rLuVr+YiXOFgr59X7aV9vWaslapqlcaMaf



ALv9zsYV1u3TgzafhN0ssrmLBsZAqZK0IdQVhLqlpSnub22KM5R+tJQoBTJxmcGnQ4xgdq8y



XkQPXQbDVujoiON4Lfs2HvUmKKW6phhroq7kissyXf6xQEGGSKPthEtABfHcatI2sAcoa+eB



17cDjTPs1wiHAfA6UDkaAZG43vPVuPb/6fhuKIgZ2AcwtrlTFMF3UZ2axPRPFrPxLqZDTEAE



Bs8oZSgRwAFKuVM08GisFQfXs5WWco4J5LkcngeTERTkLeLCWWGRjZxqjzPyvptlu1mrFcwA



vriyTlGORWaqR1ipJYyUwyisPxMOnUIvQXIszHoVBUKyokf5OU/9d4mMdtEW0NpQA4zPkJBR



Bsj2o4Xba0m1b5JJjkyRvwtK1+nVQQZyvWRsHyZrOqnFeK+qnmSQYtfEVHzw4iBr1/EnDLeG



9iaFP2payg+yd63bV7Um9cxPoXf3M+U9xwaep5j89BY9X0dK7HHCtPdz09OZZKUUP4fUW7r1



5wrxPL0//VTTtlCsDrW0Jd+ke3ob60q62OgTY5F7DrIhFGs/VWY0bmE2N1qOK7O1aHmxVovO



YJvP1+MDV6vl8e315dxltq3b2d5T2TR2JYpHRrLDpVLrKRxosxCyhLJR/YiSH8IyXG0pJFf5



5jKlbqmlUD0AjZtZU7K0spy615nr2xwW4kq2PruYLFTqhXxbMdq/qZdJj/nC4OR8fBIF+THi



W+nblGT7+sM8RJ1nH5RzmSg+3Nqe7GW7iwHmpe0uZIrrPdvruaYOFsfF2c7lKLN1uZrQCZA7



RIkYl2iMExfNIkqCJO2aVZHPAEtf09wKmq+dWwtReSxJbFsodxRoqfG15DkH3tXwbigI8p/W



HWkDxBZ9qXbnM8kAyrAbK92JchygHgTxAo1r2wrRAoPfz9KNyLq/qq5GW6l7Obf3QmuSXNiI



sDaBYB9hYPEEdSO6VkMbLem5Qi4aZnemQ6z/rqAQFRxS20PWj9eUXhZoZfCizuY42UtUWi5Q



534IWkrUQfTpFYAysXoxZN5uYkCQ8nm2LWL9RUv8geZeGt4OtdVxycC8PkomSiWrfzFVnvgK



ez1PcOxhJkAnDF1j5AzX18nlclytM3g/uYQWrTN2SAm5F39YA4UkR0M0empXyM/B8YfX4ngY



Zf5OpRoPkF+zSC0lbE/iwhyrFi8zwnZyfDYsTs1n3llZTXZUatE2jCgKnf8T5PBu8oFAJOfj



UMPBXnKWOKhQ1mb48xpGcyd6z2zpevfsYiG7MBuWssX6BOMT85Xa+jCdFJf5nI1Zp3ycYKLI



0Opi7symfHSuZ1uyj3ZjdrHUUZ2eDRMry5nZqJb7Tnc31eEsI/RRMtjVldvsGv7Z6UzH2mrX



F1fW2UwvxB/F2XelpzvU2OioVsglz9WzOZo97OTFUmnmwfVT8pf7d2DyKBmq1dxIe2eyPcll



jq3Va3ew85A7T9AznyqBMqNiKOzWICw9VABLhs3gGIDsaQlhdetOYM1ABVJJPPc9RO3dDe+G



gpgi67YDAPlI581QqwgZUpsFC0jbIg1YM6JgOE8HRAu0CbI9IZ5qqxd6V5nUR1WLvvW0H1ti



UEFpHWEq+P0o1s4i+/utV6I+ul0vMMrwDkS/g7bM5sVlluPCeMYACozI5ZnmkmXQinURLWeh



11EmUPbnign7j2deh1OXKEVOMz9plkGtg+1IVikp5OPN9f6OzrCVdkKmvJLBPRbzigvxnQgI



3bUUdUlmBmtnfdZ07aR+v0BvjWM/TN9y6JwGKUpaa8VjSrb+SfKKt9PsDOs4Zicz9W1soXsP



imnepbclrvFQAMH8JI8z944XovJDzyzlppgPyRLhJNLp9xZI+DIKgnDXPgc1pO0QIF+pMFmV



sEqhMB0ErpwaiLLRWi3Or5dLRYxVvEZV6WKBXOALzOreadKG19TsQBz6fn2+XD2wtt50X6Wa



LLFWZ5oBkLcZFmdQNbNQZgckBr1XWlqjgXg9s3t9PbOwVIlfrq5GQ+v16odJTw3j9WJnZ7ab



MZVyqVyYaC00nyjmyruiQnZxdSkMY1kmCtB+db4w1dyUaaOKuj9kaz0rMevvKzgVZ44Y+VR2



hgCKnjakpcsoWASW+B4paNKZGd6DlOl4iKWKCmW1egIMA2lh6fKuhXdDQZD3NJhwtd7ELia5



iKWwrkyKhhldP0kXKe2OtC7pJDhn8OI9MRmkFMATUH52NUo6yvl4idk6873xvWv/TTIWf/uf



/pM5BsiH8rmog/7VAXqtqEpHVyeW8t9uziV34HG9wIDfYDXOTdLXvxOHC0WqKVSb4xzbGoyh



BPcxONiLN6tKHGXfborq88xR2oSkLlLFusTU9btLxXh3aKVrFeWgu9XRa6QraafU2lIohGXc



o7ZtzI6IFew3scDvgw1zeFMssbNtkZG3VkbijzK2sC/alP1adzG+E+8tbcwtwzhEMT14m8pJ



Fl10aknCso20camCyFwGyWpb46h8pZSZYEL0+m7avsd57n0AEuX/DUq+B5no5dl+cB5YjaAn



NvVBVeZI6ZLWw7fh/3cHXRotTDehA4Qp+3FutonlvdBklSm/7+G5e8B/YKyQKi4pzpefoMBc



g3aXS4u5mVqNKaVRmW9Uu9ZLraN0YyWVUnQwm61lWT99dmo2c66rM5peKVU/Tzxvk8LRtdXm



wuZN0XPMvbuP7uvCWrlWnV3MD1VLxQsdHdUmZkYuQUvsVnJnvqnetspcvbGpZASaTpBqp55g



ANIu3RGOypCGwEa3Xb0aFTEDLgCrXQXgO42SZhvnLwJp+q4qB/GlFs3juxHM1GfAJTBNVnW5



A2nIDGulSflJrsvMHpTAVYaHa9nkTRZFv8o8oRV6YopMBulgbhL9+91L4Rf+fvly+AWVb7K9



uOOtkF0/1NxW37qpl77G5cx5JntN4HNrD76o+F7sbNPXUJCEqtgAxTtjUYzQU/zS8MRzoURN



RpgYVKNNxDqIZOe2iB6dJGqeb4nbsKpNKNIqa9T3UGJ00ePDjmmhyMBf3nlNtKk6KEEk/tfB



B3hvnXX2k7S5mnBqd6DQFe8vMNNqeS461dfBJlIdTOso40aO9lFTPmkhDnaMDptcmMW3aO+m



1QZqeGn9GiOVHCHljzFX6W5oNQDN7uDeL8NzrH7y85zvBONgGCgsVpc+Bj4NtLIqykMkkWEM



eq6qYSqJq3PI1hgOMAZQjvdz/16AstE1EOqnkb+PKlL1cu1NVjZepIw5BR2Nfy/gG5V6rVo/



tr5eLy0uJ/P0sI1D09WVUu0t7g+AHVBkC8ukf2N5Pr/W0bx+11KlWh0czV5eXU1majHeMCv5



q/kOpldi/HAiWKdbujI93zRerVVpLyR0ZCXniEelt3ql0pvvK8D8RMASweC5QRnzXEWy5qA8



eRwGNyW8GyXIjQn7CD+OAIvLCtgMJnZ9qHN18XJ5iXMz8sMIiVaAHQ/CQmstTDfh2xaHTxM4



ctiGiY2YVLXYUf/K6vjBoRq1zOzubfdXy5WlmSi7urXYwlqGclKbWcy8uVChZlxnnH5D+U7R



mX4EX75u5TbFGD1DKAx+hciG/1qG6RiszR0jw22s41hBae6fziUfWShnj7MKqpuBls2QfgsC



NV8qZYdYRdhHh2t7ezvuQmtMCqyh2BtTFHbzPddTPE1J1cV+ag9gIbM2cuuVZIRqzizuRnew



RjEplZMWlP5QRxe/kC5VbQAAIABJREFUakkH7QrG3dMqxZ8TB1GkK+cWOEorS95ngBaT0iZV



xr/FcTtQeAxdgDylSqLw0OGR+qz6IY7dwEAy096dhzh+ABwGlh5WT1Sub4Fj4FGgcI7Cj5O5



TOECHod28Pth8A4wbq05Ap46+lZwvXYv+DIwrUxTyYzHSebjiyv5yWoZcxRR9OdZg5Opt6yv



dz1frtbamWlwZH463zK/UDyTa8qOlcsV8zoMhoBVLBVCobfU2AaUFc+lkTLqPRXXc5WJEjmd



fr+LY4NmnL77wQ++m8FMd4ABIDMsEudRDmxVGsycArCfnFN1D8eoy79J7YahgozrIjrYm6Mz



bi0wH3duYX6RPitapT/zK3PJlm37r7z5jdprzA4fml2l3lvLT9NTzKTUtOojQ/82vSSPwCzb



GlSvslMYIKxLVCDul1nE+ArcpuCImgpJ8TQ3j89lM1hBJpsy06nCBCpcDdVK5YzNDpSt8BYF



XcKmnzuZpr9ArxJjXNF55kTRfR+6mMJ9lsX0F+mfPE773K2uGX8LCzOLhacLmTrOFcJ+tnNr



RhFbOjtDTAfDIuMUnazNYgJuopDLfIVaQW8GTaDn2u8/5fhZoDBi7VNaUiKkApLn+DaQjtLb



OHzX+FSgViDde4HGQwvr9YPga+As+EdApdQie+89KIffexD8GbA6p1KtAZXVNCi49wHTKI9J



D/7K2GI7jip58jWc1JtfYYDy9TifrMX17Egmu9JFT0e5NN97scrSg3quvBpHzZO1ammQ908B



41b4I2AwvfuB6Vc2Tbv3pZHtEEtSlUdlOQG+CYzjpoV3W0EWSKnCaoaPAzOn5bmRCDJ4DzgP



HqAhAoOjF2kPj7c01Vi0E21dLDCTbn15jjrwyuOPf7D+m790uv7Gi2MVpnSt0UW6Rj//FNM4



cK6WVgkULom0CRnpA+2cYy3t9YkHAOu14nN0EV9eYtfaTTXW8mG5ryKz9HjRWcXK+RDDsPgd



qlEIhDNj40vEcY6BujOMSQzgt4shtXB1tZzpYbivE9HchWAwsBxfgYCvIPDtUTYMMALPNtH5



r9Cb15Jn+HmVafyURC1UN7YwtWQul0+WVsv5ndTI7yR+BZ70pqWpNLsMtKbC/PwUUKi/DRQK



8pQGhXMAWEVTKYxD4RGNatgy5+Lr4C0gLxS+/xn8A6CA+X15IH8UQBXlJBgFnwTGvQ9Y2jwC



/I6lmUqldSfNyT1AgR6m+nWWhV6n6JrDbTFz4pjSkJbiTEZli/mokpSv0KU8gnLweKoA8D1V



NC9YghiUDWsXpt00+k3zZFr8pnIkHR4DXwZXwU0N8PemhBliVXAHgMJm5lQag0T/LJDBrl5j



TkbmSdaUZItJrW01jlvjclJgpiMbBCRLw8OXZazvCgklMReuQWu2Brz3HDgN/JbX/M4W8B3a



FywaCvv5wUKjZHYyifdgmh5mXB0mxG/wzG8ChVDmvwK2MEN4lFbs24Vs8jZzgfspA4+ul5I9



STXq477fM/0ncAmxlAu538/n406m6x9mT5HDuDrt59nuCptQ0RgdxDovNTWHbSjJyOIi1azA



NLMNI2H6IUFaQmhRZbjpUFgtdc2redaSehwC0lOhWgHmTx5KIwXpAhgDKpHvDgLT+UPgS+Ag



UNiHwRCQTub3G8D4fP8h4PvmsQKMR8UpAhXbdDx77fhZjkNgDmBo0vh2cfRZ+e+7Pm8wn/LG



PApLPX9Lc48G82zevKcMmT6hYkgT7z0B5K2/R4DfuGlB4t6sMEHEe4EZlcGN8BlOTgAZzViH



9fDIBURL7UyBwknCZDbOH1nB+xQ1HImnNZFwMkxiV4FEmQQy8l7wKNgJ2oACorBJdN/7cxdo



sKtoc1ctt5WFF8cYVu+hssyS+Nw3ENY/4Rm/8SB4A8iMOg30pdbitotzq+V7qV49Xi7l57L0



qFEdHGE+k3mTcdtxPdFKNydLWRkgLWc9Z/UqIxVxtIg1da0KHhujCy4BoCdv28pqRqcLZ3l3



CkgbhXsHUKBMu/Gab+9vBu8BvWAI+KzPKOAKi/w7AoznIjgHpM/HwFawB9wNXgCWTH8bDAGf



a3zH/FrCSC+/o3D7fYVeAfRZae19BXMIvAU+CUyP3xsFzwPT6/vywXQZ/K7pk9+mUZ7kgTS3



tG8B3jf4fdNt8L7XTZ/P7QJ+3/ffAZ8ClkKvg5sWJPDNChki3g20FjKjEQ5yYkY7wWqSjTrp



AmRRVXyGnqFcWz3HBN04ux7XWJB03apryW4MEs1wlJknHwaDDK6vwpsWprD0Q0NnewxSt3qd



ed0tnXHUxxjH2ZWk2DmeJPey1LTMu7/FXPvf5CiDJbTKJzNVOIZfwp71ytIB5OKvU31ggDMe



Q7CJLu1ytVohwy4zNWSFx3+Y/uwS+UAA6oskzgFJ/tOfFKhuhGSYXqDXlthSgfcVKt5JrXOB



4zagsGsR7wIKAO+mR43CMaDAngJaVoVIYV28hk0chdUllaoHPA4UrstAZR4CA0B+e70NSH+/



fyfw+9JhO/C+6TO+cfAEUNH6gM/9GYAu6Td9TtqZNuknv03bAvC6Qi5Nzc8l4D3jMO1+33RI



D3+rUCrXMFBe/GYEpIc0go5hADwLjMtnpMfb4KaFm6EgZspwHHiO0KQEalxf4venr91jjl+G



7tbkODenq4Xkpe4kequU1EtMke6HqhJBS+ZRBhiHiuf5UfDJXGh5DbyNg0S6TwtMHq3sgA90



LLGBB/3sUHedXq0ji4yHrDBiz3pgxlZiGfoakDHGLUNN106gsMksLZnCoRAMAhmlEN0PDgEF



aZIkyTjSFKF0adUpx28tpMz/BlgFKqRMVegqwDhUMuP0WZmuguwFA9eOWk0FzvdfAQrDGDAu



0+nz8s/rfUBhVhAHwPNgKzB/p4Hp7gYNay39FFatr2lSAQeAaZcWxiXfNG5bAPlLS6GTHE2v



Bs50Qes0X6ZzD/B507V27XiFo3SdvXbNeEyjR+ncCvy+8fncEDBdptd3/LY06gd+z3dOAt/7



EfAkMO03LdwMBTHzMuAeYKYlkqFxXcvxQSAjWBNF5hNGp0P0BlP73sGJ9QGW422iAVKEMhLL



OBxc9JxDGo9Efi9goU4by3pTprG6to5fqMpeaFosssiHIqgIp3Yz4ZFO2twb65nsxVpry2wo



4cdtQyBMk0KhEsqA+4CK8zR4DphGBV2hNh9vgktAYdM6voqMXiBZPBchjM5aTy2mzynICiTP



XG9wGsdLwPgUinuAAmCcCpUMV8jMp4pn3geB6ST+VDhUTIX/MDgAtgPpYekh3U3vC8BvPHTt



t+9MgM1Anps36dkLLgPz7zdMk/nym8antR8GB4HpuQiMtw/0APMj3b4DjKcD7AHmyfhHQAEY



n3lqBAXf9zEwKY2857OmweBv8+R3DNLVvL4FjPfngc8/C25qkFg3K5g5mWhGLEYbQeF6AmwD



r8HSJo7M6wud7dVonj0/mRSaGUSL2vCl2V9uK7r70iz9vczajfRiIvEUBIXkGKXykvMSWUZ9



gNHhu6EfM+mTEktkM4ir3zrE+VW6ftleo15v741OM8txMaJOxlSJGt2wEl9BngtNhf3dbNDA



RMgBHFq/wrXXr917gKOMQSAyy4wh8kjxG5nQzhqLtdUsa7sKxdidpEr0djFBmKk0GZ5GYCJ8



E9ME2sl0b5Y8ZfHAk9lGde1F7imwutHBPx3dPGSETA1x7btAC96AQrhCPBc6e6BjEn6SiZsD



OsfiO3gKxo0DzvdwljFAHIcymVD+6Q+HU6eGQp7+6mnelc53AA0TtI4QzPbzZOc0MxN2Mdnx



OO2qCtVbvBalPYBdPMf9MMeUGmbtp0qiNb8LqEAYg5SfuzmeBAryfqCwq9Aq3R4wCPy+aPBf



vhVBO2gFc8DvKSPGQxauG0Dj0cionB3Aktx4NCoq6teA8d3UcDMVZJSUK3x3giGggEkALdS3



geF9QMvkvX2slb7KA7Sho61cbMYBlFWipXItwQLi4Z1ZUQQeTQkjM1Cs+F5KjTuTUIPxNZZu



1JNikXiKYY65VBVa4vracgPRSYQnVBdr2xgl1zrm6IZ030IZKLOKoYDzj0qymQb17i39YQaf



ugrDMGgDMhIrH7WhW+cQ+imqc3yzuoCHREbUabuwym5DIRgopDoA6HcIe1GKVwtJ6zfJF3pX



Zwwo9vuWVEiDu1flvm2PGd3DCppWexCoINJwCLj71hQC/3HOHyH9eo7BcUvquNrOatd1a2ic



5DzwznB4H9/eFmVxoJAPTFakEks1k/ubSD/0Z5Z/rv4Y6b4HSqJALCxj2wbicJ14H4q3Dhbo



lbPUcqkO6U5pJg2OA0sAhfYqOAXkoQqkPKmICvfbQAMl/SqApKXB93YB80e0aQkOf9P7PuM1



w25QBX5zLxgCliLG9ypoPMfpzQs3U0FMtQTcAVrAJEBEU0uhJZD5EhIGpdWLfpijv6xz+SQ6



3ZGNz7BKsJsZn7m4rTjLLoILSSurz5lHQpCQChKWh07VwFahuMuBZl3FpjDf3AxzczjK7gxv



xW3U2yuhFQWpvf+/Ct9i2e/Y/BWEgA1z6Km6gM9gqyEq8koXc69WaoWd+wcYL1xna4Tl61UK



FCO1XChSwlLU6pUN5aj9Na7fhXIsIIgz5KxNZSR1TPqFuTwIF3s4Im95pojX7kBWeT+e5T1L



2J2F0PlkIXSfQ07IXAlLj+ehjerUNEefk1bMzEEgo/AxhNV4paNGxeDOCFr6Gh+JEXrsCAof



UfVi5i6/N5G+JYR9iGfnwQpd2Ie4fi80cBlAScMBNqNQ3QyEFllOcJCBTuZ2pYaDpltqKFQW



Lb6W3G8roOIyOAsU5vuA/FaIvbcKLAVUIPnlNRVEeUBRU4UyPp8xeN+gIvg9FUzeWLoUgfLy



DEiFgONNDzdbQcyAhNO6DF07l7l+V6uio+R7mSR4CUvOxOhQpJP0D9j4oh12389+NMW1JFeq



xzk20KnMR3EeJxoNuYD9Gwq3wrTrGgzfR5WgifrZBMxeRDFGa31hIjkVzmZawnxtOZwYeSOM



j18I43xvHQXYzLQSdiVPxwUQ0DDT3pFhhVFT3wOPxqcX5uKHw0rH5bV6ebWDCVXlGmnaaByb



gPcDf58l/cx5DC3U/SK+q0M188YAJBU9pJ5EKgx9tVClRKlTEqV7nagEMp9HosusUN7JdimP



cd88qYxCq2rVymt0vIWPEP/9TKB8HSVp5Xongq+gXCtU1RSe9WkEiAOTZVNB3kL98wDpa0WB



xlg0f5aZA8epXi2jCHTQ0UbAeIAq8VZUQOLRYdwOzk9QdTtCFW5ngbUin7o3XJlaDLNsNmTJ



OgVUXoVaKOQaxEGgIlmiWY30nu2kAXD0GnxuCPCZ9LrG0+ek1UGgMiknlh6+owyh+te7uDm9



NeFWKIjCoOaLK0BCCDKdWYPpJ4psuUS3Kr4ZoqM4Tnqhm+3Z2rPRBaRjDk/vOL2h6Y5jNrxf



Iziwe4OwElcly6IgWsp7rFLQY5XDfOMtDqdlJRyfrYQrrMphW4HQzeTB3Tx/nqnfLM9glSPL



Ufh9EWjNJhDtrTUqZbPsNbupLQzs7i2eG5oqL6IcCmwPuBtcRYCugFVQpeqDjyyqU7Sl4Kjr



LWQybnT5S0DImJVFybJhCUe45LcGgcK1G8PPzObaTkoVfqZ1eIVrDCg069DH0sHwSQzALs51



HLdMvPPmge8wvQv4h+eACuM/pc/LLLYM+MdgUDYTtrEo8z7eu5O0vsV1PAalFl0rrUIxr3AD



POvW1mWU0IY9DjLC8UtTYaBYCGPswqWAK/ymU0tvyeRvr5s/82DpJ3/kf+M5z1UsFcznVCpL



BkudLaADmO9xcBiYLg2Jz/od49Rw3LJwKxTEzFjUagnMeKM45TRhL8PIrdjutb7LPKm74dAq



LdkrbLqTNOFAGnb3LOv7LHXHn1Y/tCbwUhFIw0OcfBrhaeY4a3WntZtenC78WK1QTXDT5w1X



/gWe3g9OA0sBrHlq5ZTMO7xGGjbptIPFHVvvPhotzq2VC/WtH72yNsly8I2uxgEErYsSqJ3v



bUMpMyzc0tO67tLxeMNSJKpTPIOnnFSwme3PnNWNqpZ181ZgkNkKydeANDENCpkG5Ay4DBQE



3zXcD36OKtHb/NxRr4RehHwKYXbHYK1sM9/R8lsV45DSx/cMEc/omhWnq6HAeRvKNcu0wj6W



DmxmntlJfqtUzDam5AG8Y/qv6Rie8SkZya+zngdY9PUAxkeBNv0qvMZDOVLQtfxel0cKeA/o



Awr5IFA5PL8XoKNp+09aqADmPy01ORpUBp8xvAr2AhVQJbtl4VYoiMIsERXI918713p6nUZs



Zkcum2xtzodRlrSyHV+0lVbnabpoW3vquelSlDStZBLXoDeskgrmu2mAaY/z470cr6ZWLxfO



ri+HHWxIs4e5UZO4vezGo8MlHpYJx4CWTiILGbgT9IPX+MYyPVtUu7Lt9z+QGT17KT5RKE++



vbjIXN6N4r+T7zzM1x/l2a0I1jADkHZBqxS5GtYXS+ukRdQbIUPKOKdQTJWnhXNLn/PEdRoo



XFbTzIsKIk0UEo8alCbgfUs5Z0B/igenqRaNcZ6jjdDJ4GQr1Z8y166gMHp3xw1varXxEJdW



+Wy8c0IySAdwa4MKv92NCt5naJ/g+wVhhHakPjUytl98xiqj76tgaUnIuXTI8q0B4rm7SBuG



ttcCpf8+XmUx4ab5OmO/PCOdVfST4CIwfxoHaS4fVaR9QCUwv8YrfE56qBgqmcpv6SNd7gaj



QD7esnArFKSRGbVfK/AwUAAkDOs2oioucbfhfypeW6cKQV05H+e+jh/L80jGGRxnHUDwMFpp



V6gWRuKmAYY1YxmfgNn7ea8Ms0apgGXYk/2upJoZoPqz1NQepsoJ/qCrFRuDliAyQaLLyB1A



izkETF87zCddSes4w4nMq9q0bUvl7YmJ9BkZpjLdCQfdJmCOb8Z8n8FJqvIIHBHb9rBOr4K4



lDjlNn8UUHZXsIQKp7j+TeLxuyqAQqLQWLVQKbTACpJCYl538N5PogTszYMzNxvjBXwbU41k



Uc024rMKF5PXF2hgj7AOfDvpYLpL+k3EnBTxj3w1ql9oKz1glCi5HO0h+qsrZVwoURrSfjtH



ktl2LvTyvopOuZi+j8eFtJSRdjigTJXSquQxLuwk75SeWTYyWiX9zhy4no8Gr3zWd+XBR8FB



cBkoBxpPSx+hkhjkjbQR8uUBoOKocN67ZUHrdCvDl/iYVa37gSUBpUrLyVxuZS8aoPAOggeQ



DC3c9rmk/jgcXqLeIJvSrda4rzVJCQkDrZ/jdyEtCUZh8jhTfo9w/wpv2Htkt9gK3oN7r70n



g2REI0j0BmMe4bwDPAMqy3Np1aAyyWYK/DZoufyuAizjmc4VtnLzEtCdkQIgrPPbe+V7aVWF



dPgs09xZ3UhVhut+R2U4C260iCqFJYzK0wh38N4ufrjaklnM+JliMT95HaShPYuwa2VL0G8v



bauL3P8tBFaXSUfouWOJPw16qlYokgZJJU/bJ/xNq4EkErd0qcLXWeS1lXjO8/xv08q/h8bN



AO9b8rXyvg3/svlU2QgKt1W2h+g4YFvv8lOUJNxOawrm8UEwAeSzeb0CPgj2AJ/TMBj6gPnW



aKksBhXjvvRso/qr0j0FNr587catONxqBTFPl8Cj4E5k6KsYlWUYuoBE1LGCZ6hfP0JX1ftw



Df42nHmafUdKlCIPI5nWXRUs05wqCIwqY82G+X2Y4ysw00an923cFQB+QBRMbOtGSN+7du7B



RjCOHpz6Ev0Zv0/BO603OuVaktAxOakDuFS4vCyDFF4ZrBI3YbG3UM0ZJR7cEHDVHi1KEYTJ



ksTvWsWqI8gKCt4W06rFLs7T73BshK2csHNVaql5Pf2G9z5HPH7PKhttkghvjVEHHsAepHNi



FEv/pt/jgYSVkFaz9vPsaUqIL5PY3eRtC8+4OG0T59JQzzLWHBR42x5sR4Fju2y4pId8nmGq



OlXhDI34bDiJwhwhb3Yxd1KC9XG0NFTZ0jj4zjLvHMT53SnaNd+F/p3c0+q/BKxWmy8VQOo8



B34fmL9GHr1n/hq8sXRBNlL6qETnwDSogFseGoJzKz9svd8ML+Mas0DDmP0PiiMhVz7CdmPl



yYWIBkfY0xuSN1n3zTZutIppC7NKyd4iJiOmjJG4BjZjh5E0Ql2LXqpkcPKBFcrRNMc/F15I



aOdzN3IaSBpUHEuRNMDofLEpbGYs5CST7hHkymGifIablBLxZo6jxK8wOE6A6UyZ6Kj/DpI1



x2U8PJKPfLiIR8QuqnfdCJcCiMsoSpGNRjM7VSuJPL1REm7hzGraC+2sFV/6HtsVXuZSfs9K



4iRvN7tunSAHLCmhfROrgjloFzfTTpqtlJNj+PjqpPr1JD1OKHcqWOMcD9BGsUR8U6CcfVTJ



7iHuMgI9RSeDAqzCZvD+9h7U+D1WYymVnoEmWntnGBxmb0nT9BwpqvFvB+e2f7YwfsQuCWk6



pec68TajnMdIoyXHWfAKUDlagaWWJa7puk57zv+ysJ2LvjMDVBjjalTTOL314Va2QRq503oO



AFb9IUSp+/3tK/ni4gM4fp5fWY/ugaHdWLRB9utY2pLLvD4bJ7hqtn2ZCuUUS0eYcmHvZhrs



u38fAlzPFXA6l2GKfOIU8aQfT+dv4nqmVDycu1AacewuLbYvclS40Rv6+tnUB2VCQVrY2LJs



2i4Ai/q9QCYNAS2tpZcj5X3NbeF3cFDwPOcTCNhdKA5bAIYmjgqXYxcLwNJAby4LpM+Sqgys



JuEUPXSi0LWeHWFoaT79lnV0jZWCoSqFrq7Qs7wc/ku+u584LLWo56voudc5fwogeAljFYlV



TPd47OJF82Yc8tV89IIngG0VBbaZZzMYpXWQ1ZigCB2UDK5lOcbRnixnHIyQF+k1DGxw3w0m



gVWdO7mziVReBJc0BnSfdzN/2u/6DWxDagD3cLQUt0o8AlKF5GiQd8JnPZpnq4rCGoaljso2



CMjn7Qu3owQx4xLf+vLm3fuaW4cvjazCHBuF7vk9CrV2sqR1lHrJyhL+MBg6Np0YuZQB+M+y



drAROLFn6Hniuosuy6TQiqO3JHyJ+CpbBsLy/EQ4uLWnfJKyWsttT81Yyg7i4r1VhGQL7jd3



FELP/1EJK3wnUchtF/hNFaUPTIB+0I3wDK4th1/lG9H7Pxptef7rGHbcpsPFAe7NEKfKomVN



g5zneo1qmMq2TMaZDcPUlCjcN32VrtAIYWetPL9tX6gId4E8ymF15zNctz4+Sj4Vel9HUFux



rKsKkXSY5RlLqIeJZy+/FTChtVZon+b7W7n3MOfbeW7xmiKbHgVapbJEsavYb36SZ4b5fRoo



wCqa1c094OOADa6i10ko6YgwVHEbSkb22d0r1E8CBfpeYLwqxxRoBPlunAZJYzAPBoxaWkp5



/zB4CdzW0oPvp0Lg8VYFM28VS4b0wIj+kculET9eWg2Tm/HA1lZMzi2uhTtXK1lcYMXdo7nk



MRqBZ3JxhEvXpu7celtrLZlOFYbX0oYmDHoG3I8GtbE71Hh7Dz1azaF8dTAcQlHC/KWwt3t7



6F9bCuv7fiJUT/9b2Nke9iIMm6prab14oBIGFZadwOoY/E+FXGXZBVQQrfEe0jz4y7+bKbIv



B+2JjolMtPptqnIfi2qhqVhgNyWqUXBepqcC4AlgHyZONujNFDGs6caYCXumh7/O9XWqSOcZ



Y7hEOWe15nGel0aDfG87z6+hYKxsT9oTdtKlA+seokdxKI820qpQLtGGK6IMfvII77+Xd+f5



xd4hab4cKX8J8bxIwiy58b8V7oti1kyGWhu7+Go8aO7RacE+LIzr2H7bT1x2LswSXzf3hzln



FbFz4+RfshUDo9W/zGMqsLy0dFbYLwGV0GA6LSWtUH6vUrlBI9OrTEj/M2AQ/AFQOVIacrxt



QUG7lcF6vVgHWsBJGCJzDYM0ePfBRAmDD9/M8faQfbWpvfJv8UDXU15LPoBj6eVaxHSNtA8/



fU/iGt4G+GcLO1s2hWfLy2H/2kJoLbaH4cpa2LQ6y7bQ1KeLreENlKPxPfcExw329W7W7cRh



fCrFcSBzDoExYJCBPbQDlv/hj4e/z1bWQ1kcHyLn9yOjj+Ll/WnSbnyON2gpG2kzJrJ5PWjw



vWcx6Gi8wsMaRKoyUXiMNoLCN42WOcHyBd6l4zrtUVJxSINtI+eepXPYGDa6Tge7kYeBc6dw



xcrsARrgvN/Pb2muCybcF6XC6ICm+TVp5JENezfeUx74bDouglMMvofRodvXOGgWcoVdqzh3



Co1tsT08b0kjP7lkFSxCWRKV4SgYAhoc6aECHQEq0Ia52FACS5mD4Ap4DfxABRN9qwJWLzwG



zgOtyAWwA8yCMoibC+kobSt7Kd8LBSma47ncejjRWs25/XITQ1Dsq56bCPhH5nkuXQ8y4CEs



njN0J/ffFy62bgrTXQO48JnHuyMb4CAA5Z494a2FK2Et302dnWknCEk7xdTjvPsnQAWA5ynz



sM5pnVv6qCAy8UMgFaBiU/L4lp1hnCW2q5VK8z42pdne3J5YDcJDSlp1Mz3CoFApPNStNs45



pqLmx0iDz3laZhxiiRKgDSWJi7RZiozzULJ087ydEyXiLvCckwq7LDt4zi5l4/DgSLkKYmy2



NRyLYSVzCv1xlThnRnuaBgW0I30yoTTEWb7xEdJ0ctQj/RrvIPBUqTbGdIzDtJp6BxB9w165



RhXtHX5Lq2mwAnYBv+FzyyDl8bXfxqPCq7iWHj57GahMP1DhVimIhDgOVAqJJSH9ttZaYq6B



ZUj5oWJbGMdP1UcYl5rIZJMLeDmZ3hQyZ5Zy9R4qvOxxqZfyWCurkilYElhGtOGOZIAGSzw+



FrXNhHxlhh57tjbqjsv041MFYTOfkG8Kh+iFYesyYmEGIWikwTgUHNOzAEzvErB6Zfo/C3bS



eTCxdRsuNzt7Wv4eAAAgAElEQVTCWE9PPDE9WdtP/5J7nbc6n4yKyhLVEatZihI/NwLfo5Gd



XvPT14PXr4ECKO0sw4l6utvSFqRIca5QsjplJaIr1Z40a1E5qlO22OqUmgquI+o2rm1/ab0L



HC0lIEkq5Hk/yHPSbJ3SSqE3PXX2h7TVZElksBRyygq+xAI7UqXPFYlDGqFIKb31hey6lE6u



LROHNMKYpT1O0krDpfBbqijw8sc2jMbFZ4U0Np1SRLrvBtvAe4B0V6nGwW0PJvpWBInQCiSq



1t+SwyrW4LWjVqfOTPYV9vy6Cu+cOIf/0AQ/ucnyAq1aLNwaHEWpalpTGS5xTb91YJXuPM6q



YnZ+alpuZWedqWR3NBZaiEhPVAd5eBGW7aFLdr7YHEYYbT/BXCQYGP2ffOpDvG8aZLQliUU+



Vad06SoKGT4PZPwkAnrH1Hg4MDGm10UVoX6C62/QC+SI+iGE6xJ4nWv7EZ5+jksIlLNj7bE2



zSIVR54z+NuwcVfDoWLRdkC7dNdqO0uXpQ6KVpK4SGO+lbGbJZSWLa64z70KpckSP5hZkw78



SReVw6n3VocsZVQO8+BPS4ZRMI6y7OeCwsmuv/TnMU8L0O+Q0tjxFWltB4pCa53S4UBLMg2c



cdnO8PdesB00SgKqbmne/M6PAxXDODQ+Z4AK1AdQ+3RFosql0uwDPwqUlafBbQ23SkGgc0pE



LYvEtMSwyN0JZMBJ4C44o3g4bMZng9UV1nDUxqD+A1Smt5DQsynDQ4QApz1NMkeCK9Ayaayc



SXqoQBc6lmq4+2Q3XcYD2Py7jT6wSzSiCwwXTjO4Ns50baZT5HF6lkdxS3t49wIYAXeC9wHT



+VXwJHgUfBj8O/Cn4NcQngEEZpkqj1UxuofDHhR4GQG1a1djoAHoROCmEPJWxEQlds6WdFCo



rweeNx8bwQe4ee0Csp5aaFclptafQVR2bMCdV2gbTpK+b1Ft/zDbkCuUU7zEFgfpginpq3JI



Vwcs04FKzi0dpZOlgcKpQOJO1GEachQSDFbadz5DPLajLIXcc8g4csTnYGc6IZL3zKNGSZoN



A/l3BZg1SweDsiV9hsBV0DA+3jdv8s40eW56VCBhujSmx4DxalBvW9AK3IogU2SkRFT4VI7n



wQwwDRKKJka0heoJe6xQnEfxERgz2ZSEc/vy2a8ssiGM+3NQlmD1UyLKIBmOJU2P47mmzFS9



Gr2HGs/H2uPMMMt03feOuZDhBeIdpIKWxW9ZV2WZ0ek6liyJLvKqTLkMHgaPA+P/I/AyeBT8



A4TlRY6/xkTGuzl+jmpWlaMDZN2kFb/bKD2DcUjHJa65tmU/97eiNDFdz28xR+w0PWzs9oSA



Y4kZ2NOVJD61Geh0jhMPC4PKYEh/b7QZMpQOzlRer1abEaoOXIH2MVVdvVvEypZZfpuMIo3z



VMVsezA4mlavpHmB+IzR9KbrPDh28Iz0lvasAymgSK1T9C+Uk0y1gFu9NRjC7vKkNZMqkxt5



KsxOmTfPbFKczjNjO4i0nSbt5KtGz6CwWxKoCINAYb8ELImhd1pySWNLV9Ng2lDO9LqyYNYt



WR4Ar4CGwnF668OtUpBGJo+QRQlmkf4BoLWzfioT50AnRN8LjbSIH6Q0eBNmYDKjox31qItI



mqv5zCIVgHGeVbBVEGE86y21zAep9VTZhO/32YYa3z7xAD0we2FBBwxnNyarKKlCUsQnb6OX



MlCGfA58FLSBc6AZfAr8DfCd3bvDL7M1QB2B/69Rhn0owDxxWY9nRox7iUQlsuBAnRbzTdCK



EmxBAao8ZzVlmm7nZ8nLIrA9pFXXQrfyGx3esKQIYLqug9/cIl1UmaCD3a5xvZpld7Q2SqJ+



XKIWMSaTKOHKndmw+Z0oKbfnWGpMXpmLkqZL5XCsBb1Jp8DrX1dBVJEtXS5wPgbeCVHLLrKL



5vVcZVYP893KbFVCKWcbZGNU3RJkY6qMa1vIG/c0TpYKKoPHIaDll5c8kuZngOMOYBr8tqXo



dnAUwOO0hDjIUV4OAWiYyoHvS8fDQMUz3tsWTPytCu/wIS2J1stgFeAQeAJ8HRi0KAqpVkmh



16HBFFrMPsoOSrGV38YIuulWqYTWSIHYUXC7WoTuKDuCTbLb8Dyc5wEtp/X7Yc6drSoTLcEM



MkvlUCE2AT6XKkbvtd8K+8ToaPgopcchBMNdsnSwYNpUdGfx2l1rA9a8mS6VarDYFM6gIMX1



1WiBnaE2sQHnJ3jmVeL5Ciq6A0V1zXozitRFvE7E1OraFavyOPlcTNNjVU2qWfzWd+GYvoMx



jPbJehjeSs3uBHJEVbSwjP4c551W4ndqJXYlTV+DRtJbJRSuvXFcZJLzQUC1sK2b5M/hfIIu



6paleoU1nZnl5ky2XkC5bbQTNTzbmOpue8dgdUn+SXsNmwK9kX5OCL7zYYARSulS5Gg6rC4p



8PJZno2A06ARTKNGW36MAuO/reFWKogZ1Uo0Ak2E1EPehzgqcAYtjcRlPx2muNNDg1+gaeaS



XJ3N1juSetSHgkhAmSOvfLYfwOTATsdhNVcNA9Uk/wgR0m6u9cOVAay+BH+Chz1+KxzE39yl



U59AZD6Ozf42W659l41jPoMeoiSJVlGmq0hat35KjAGOu3ifalk6Iu9vG86MY7AbYNoAZv1i



umcQ88BCvIeZtbuLxfA1Rg5frceZu9HrQd4/xlYD74/ryVsInkagBWvtFHY7Hpg8kC5OmmdO



lEtsnSHcQZXxIHsUUgo1L2LlL9OPgSKs3cW3ShQQ47Uw+kO01ZpwjXoH0tVBnJO8J19VdktX



jYF09bfG5yykM93sB9m8hctkI8+3VqBh0sHq2j/OZc/eS3n0PvJtD1vjfYXX+KWN8UmbZ8FF



4DPyw8DnU34o+N8BKtNfFqSvCiA/dwPlQSVS2ZSHBYCNu73hVivI9+dWojwHJNDrQIaqRBJt



jUmLU2zvMbMQ1/8aWySsFNhcp1SM2NcbD1obSuKzvqPgZ+jNZ3u06ApUfo6th48wh3Ef/TzW



YizeJfYpROdAuHzqx2ig36flbMq3feP9j00sPPlkS4nmBPSwwylNyyBHg/E7z8o6tqXGGPC7



DroVEOYKlpbqUPadQhj4Ui1M7YnD4heYGbuLwckPM0K9le7qZ+N6ASFiF8AQnazHtYO8/z7g



ShPjVSAswRTIbJFp+3Tpnl9n05tarWkXejQEzjDMQ9Vq5EGaMb0Ml7xaD4vHSF4XhmSEdxH8



VMA4pEHeSkcVQ2E07Rwj1qJn53BTdLVcamKBWqkH90WX6ZziOxE7b7W4+IrR+nTEHXtEFW9D



IVQuLb/5l29+0xJBoW4oB6fXg/d8znDjfdPjO+Z7B/AZDV4nUNEGwBDwHWl/W8PtVhAzfwn0



XqOClqlBVPxPhQGmm0zSP/ot5ltPzUYxrnUSGd0ozhUALZQ4QT2Hkfmk/VJUvrMpKfTSX3oR



ERmhpHCNuBbpceT/w9S7S8zUOEtDN67Uxu74xpPhWeozlBzpfoYnee4ZYD0bHUiZeZSjVQPT



Nw20oihYCqtxjl4Xse44prYUSsctpmizOFj3EP2zbFdYHkb43+BejurVKMdTQMF4AtwBzNMS



yHO/l7UZA/VKDotdGCGaS3jlGauHkTuY0b8nG9pP18PSTqpFe3n+OaCwao1VXOPUYFiF8ajy



KXjbgemmdM5czOdqbJ9eRUCbcB5Tg6ZUCKnCxaw8YIq0z14EV4DC3APMl6WGJYmwyozCpUKs



MN8YiCv9pu82wvc/o/DL60lgvLuB6ZOnB4DvSv/bGn4QFEShsxGv4EswmSxxJP5OxsPewoR1



4TOqJ60qUUfnukw37RJQZmjdMvO4+CmsJ/ubqqGPyjwFEKKWTlHPnIGnxgvhc7VMsv0qyxuG



4nD1IQzVZq4TSX6GMTjSUp9kpu7S5v4wNz6aCoK3XwGvgseAJdEYUICeIwU/gxIgQPVDcZjd



xncUTOv6pguloxLndHwavEjI/RRnOM5mpjJKTeIt2czHMDDPU4ipM4HZCc7p6nnaHe1vZ8Pu



tyjd6CVbOcAMfb6fZ+FS+XguH7/O4OR50iCthoBpUlGkTz+g2pQqjMJtmhXETLE5zKyXsqQ1



4X6eUsHZ+bWuTLLrTBJe62cYhM/jC2Yj+yqzJYfK63eolqXGxuvyriH4HhsC7bn3zJOhca/x



rNdU2oay+Rs2p++bh7uAfJaGtzX8ICiIRJMYHiWYR7YNoQimvt9EL20x1Pci8HE+zq7ZTQPd



JZzP+UMrqQDMZEvJQwhifX8h+tJYrfoAN/vpaJ0pJIUJZuoO8wyKUp/G8h7G58I6Fp9OACav



o5O5TOsYOyLjpZEdkdhGbf/RsISCyGSDimsYBJZEfWAKDNM7piX8OyQdBxTs6IdQ8l3HLhY5



mkaq+2nDfprUunBJj4VOFNzNfS2zeWeFMcLnGAoGoLpODxcJRGGv5MORF2hrsET/rUOkrQUX



wyjL+LFsrvoa6j/M8wrvSWC4GyhoCt/rwPTmwR6gsF5oaklaWtorbL3bxLVoB/l/KQnr0C9Z



6AiHR5bDC5+gMeRaGtOrspHMtBPFvKhwO8CLwHzfGHzuxuDzjeA9f9/4jMZDRW5ct0pmNUtj



+TY4AOBNqpgcbk+47RpKthsEkgIqiEJJJy2DZAjmIjMtqvn4xb2tye9RItADY1s2fcf3FC4J



PQTYzZtNAymqWYT0w8yg2IlEKIA0KmxAp07SxpgW8hY9wTi6LuE+p3mJmfRbucdG7OsIdKyV



bGHxT9P8dGq9/IYwqIQyTyb7nMalIYjf5lxBvYun9U6oEvmeLWAF0992r5p2dIM4GFPgOafH



zwE21k1HzO1atTuZHZpydK1ueYa2xlwlnN+FEO+ifUDVanpnEi0PoGQoYmS172VgPj8DtLyP



gn8F/i5QsU2r1Rird3PdXWF0djJcQOkoKezwYm5uwItYaHqHjWfxAVPZyfdnSaQlzjPgOSCN



paEliEpjvDdaf36m+fVoMO8qpkeDNPP5xtFr8tlnGqGhIF6Xln5Tmt/W8IOgIBJAQko8Q+Nc



AiVMoj41E8V3f7cafjKOsKtxunWBVrJR+jXe62IKcNzKaoyWKMFJSipw6BT7cgQmm9AoRFJp



80P4jO4ZXYDVArMLTR/6WFNTS/saDHK7Avb7YJBsYe56/Lyahl7+pop27bcMHwB/D+wHvwNe



QrCcA2VXLd9O86IrHecsOTrtiLRKbc+Xz6Wj1Rzlg0bB5r7r2Tczu/3ZQnjs+XqYRBFmKBl0



dVqj27XwTCbZ9FqtGj1A0WQaDoEPgaeBwvxL4H8FKstxoAHQUtsojsevsrQ57OogCTsYYhnn



09CmTsnQdGU9vNYWZeu9MIDSwXUnqRCbZ3li0CAovNuAcZoXkpuioQD8TI2CedoCVN5mIM82



qp8bhkLluOPaNQ4btOLoN4zL75j2Bp85vfXhtn78WnYbhJUJQkK6uMD9PFvpEm3J1rMzTdlk



qpavd2fp80WKZI6QCRb11uVbWPxaZOP7yaVi/PxqOXcPS+Y66xneSpYVbi3fVli3NYlqCOoa



s/RaubaWfeqrYQ+1IHqJWqh7R+1rK+tNaysy3+Qgvt9jnqWBDPSbpvvj4BEwDk7Qm/QfOfrM



fWjfEjB9c8ABQM+dZ6VyOBvWBnzqVocPWHGkv1iPOvWWepKbzEYHn2VHOKpWgycwtJj6Inu1



Lxxn/PEPsBIzcTJ7jFV8H+Q1La/fPQ0OAOny52AX+Ag4D14C10O1bbmHsnAfHkppC2WKlCCo



b/ZCXB8/wnQf0z9MvCMcNVKNIDH8fQbsAVaHVB6h1ZdOBs/lh8ojVA4UMj02aCn9LB28vh1c



At67Ckz3PBgFKlj7td8cbn2Qabc7NBREZW0QFf9KkRafkiC6uylkl3fX82+21dK6ugTX+ohG



kNhr8y31l5YjdrVfz308n2R7qa4sI5AMgiUy4hjQSn8FGWLArcrGU62MGdRp/KbrF7idUdhQ



0HTPDyfopRrCtX4g45eAwTQPgCfBtwBVlFRo3s/xd8CzwG5g35fZDvqZP+nt6LjVLes33lc0



/Bfn8iz9yCEQSctsNnn/RRyMHKHU2MsTWPN6F9NBWH28/PCm8BF8eLUoqFrYl4GCJT1GgNbd



qtdFcAg0rLDfVwgR84RnsgX6DdaoamI8kkGWe/GNRBoZj/nZBzbSx8m14G8NxFlwAUgPeSZ9



5YEdHsJrGg0VwXdGgQpsmj2qtINARfZZv6siGOyssUpqHoxjD7htQaLd7qBVkugKvnVcGXqU



Mdx+RjCqxVgLlxwdC/X3dsbZGSpGGFCM/0bwiECnQkjhgTM3FAWlmkW56IVJJ0My+BANMwX1



Mr+NH5blYECGtkkWBtZhTN1vE7I4pa7JEN+1+tP4zo108poN9PuAjPxdUAEPgf3gw+A3UC7m



k4X7r0XgQUFgXDA96mrHCesqjKPUqYLUa0zSjRhVidbvqCS//lPoJOvGyt/EmepbmcqBvSj0



FkqUAYZO2P+6+7V6KO9HwQeI4ztApTU+hVIolMugEyh8BWA1yy/SnmmiCtNEb9g01r4+RKvL



vjCFXF5IJ4XfeAwq1rWsXD9C4rR09P5fFSwBNC7SxXhNg/HYljO9xiHt/I5KIo1UdpXENGiw



DoPbFiTo7Q4qiMRq3dOX7nfRgWn9m0wt6o3oosUFlBpxmWm6v1HL5EbwhCIxZZgwSOB5kLSX



itRps9nWzupZnJpQE2NQcYMhMsWF7Rv5zVWnqRkQT0RVq6nEp3dyPxRblpeZ0WL8KAyTQFx/



ssE0GSezDH5XK6tiykiPfwSeAz53BLjc9d/Rw/VqlQVUVL2sWtnmsCTxXdsopikVOv643gOn



KGygXG+uZpIiVZ94G5/ppgZ0KmTaSW+xSnfvGQqf5vnw1gPstvA09TbzfhCo4J4bPJLVtDRR



IRBSZ0BnaWcgqcdV/updPEJydLyiQ+3yJTq1d0Meps1k30S3X6O6eZLHVRjzI7ifxmv+G2mX



njcizQ/XDCqDpYnGRuWQR2PgCpgDptOSRyXxvjyQnpbUfcDgO8qGdL0t4bZ9+PtyKyFbK9Vw



mHGANeYrvYBoKngHMOJf4WR9KapvQb7aS+ykWaun00G0NFpwhdjAfO24v4hr/7ZquA9p68BE



sjdMssCiq6toyyyUTp/NdyfN9bX8XqZBMcViFeuqc+q11zPZdrx91I7xGyFIvbArYFuBAuj3



FADTpVVT0LXQXpOJChTWOK03M4iX/v4iv4/yxDbaIxRwqYD5vgK8oawbAmJD3sEH4mxbp21A



g9ztHGp0O9QfCfW19ybR+GfisDLPfCy6qct9feE7Ty2HXxqANAh7GAJWX1Ll46hQmvb3AIWc



uBLGYfJt85PFO2nCPUreEVYXLVZIR+3L4H4a/cfYguUKW3PRo8eGeBvdvJO8vwS0+gqyQSX5



y6A8Qc9UoBV8BV0jZWkgraS/tFI5TCOKn9LCZ54D54H3TbPf8vpeYPDZGxUwvXiz/zSYdLO/



8/+I/5+Ff/Y9O7EhJCew3cxuTwlB3VjrE1EVsfcmNNG18whTTJ1lalDIxI0K3rIecq1lXOOw



2u5NRuemr1HT+pgMgfDZ8KsjIbrzE2UUi6WHYQ7hTxu5PSTmc/X1jg9gPXHtw/hAJm3wWj3w



Owqe8OudwGs2+mW8n5HZ3n8KKEg+92lA6RT+DbARbpUr7cniaOM8ABXDBrzP0/+GPofmZxlX



RLjoyA1VvMWX+qNMtTXKVYdDdvQT9Gr1xNHUlvGw/yeIQSWATuniLtNhevwmpUIK79OLFx4k



P8S9ucDkxA8ySLqUD0cRyLr5YCS9NEWS8XVVKOFKrIu+DbwS7beNwfW0YW48xqvA9oJt17Cd



IyVU+nsHR38r3BoVlcP3oHWqHMMcR4ElCMqZptXnVCjzf41HKV2lrSXKcWB8fu+2hBsF7JYm



4Bm62CeZWfSvwy+ElqawpaM5/A08pR/O1Bh8Y8cm1jb8MBa1g4r6BRYmrO4tRr9HJSk7n4n3



1etpV+8ECZ4FEtbQXwy57QxBr7Nf87lqPduFO45NdbwG5pLMFdogED2Kzz3NpKmvu2VB7gQy



wzSRzfQOrcGI6j4mrNIuia7QT8ZnYxcOnSPeIaAQyDCrDQqVTPeaR2mocKogMlZmHwKWOlrN



k9zUwcFHiE9v7fZeaZ3tzbKPTA8jzJBhrTm+cnNh4HczyU5G9RcRtoSFX9XVKFsdQZVwooBA



J2tbaKO8jHyR/BJpSB7kG3cA0/US0Ep3A4XZ0ktfXofppgLr+yiR+zKh97VsOMqOVqeZ11Xr



KIZDQwyakvcmpuJ3Mh8rv62WzDN9v2weFFCNAkYkrRJpVM2v+bYkvPFY5reWXroo/KZjCcir



KvBdSwjvHQHSy+floefeN/iO198Hvgb6AUYjjZfDrQtm8LYFTZGBCX/FzmaWl+KhHMdRB6Cy



bv7XuUUdOelDWitXy8lP072zxESm7DWNkEmiEZbLrZXXs6XwSFM5+1Fat+O0QxRQ8pjOAOZZ



ihfW0G28kEyw6xOWbFML3nH4LKMfYe8vx+GV9Xwu83M81Eefq0oh07SMQ8AkfwTsBgrgRTAK



BoH1aq+9Dd4DusAT4Cni+jZf9Z7CpDX0HpdTAdrL0XcHGaBLKvUrn8+Gvj+mmvUWXc+fSXB1



j/LoYucNnkFIE/cEoaQof4vfhiHwT8A/BIfBb4N5SoyWOM50RkmREq1pEt0mrTUEnl2FWSRW



Dc/zXRYmowT1MNPS3pJ9ea2UWWCY6SBT6L2+j3gU5MtAgTe98kQBlwX+9lwY/C0GgO9ZUlgC



KeiWJNLR+wZLG0sk82SQBiqidDBIJ+mlQToIpPNRMA6usZ+zWxBuq4Jcl27MeakadrW14h+q



zlyltdTvrdm31wfHHo4QRjjDyrCqzYY3IrPBGI9G47GJXUQGeGGlM+ROM29Dops/6v6p4zkV



JC40h9zhw6F47my8leus7Wim+6YZBiw+zGLAx1vCg6fK9dc343fOaorCjr6m3ZoKyn8L/jF4



HnwR0MxJ51F1cFTotXLz4HXwKWDQwr8EXgMy/mlgmhW2IvhZoIUcxUAYB+2lkYhJwt3MD/vt



Ksv0GSE5QXYVOPPzIfAIUPieBP87ULD+JVAx/d4oFHqZ/FpFpZTN2tWNchRIbxXv73PEV3yT



c7p6Y7aru1Kieru3UGg7s16trNMYor1XP0U8dwOt+TmAUqZBQb8xSHuDxxrYAnxGYf6r3vE5



09wIKpBGSGUzj9JB2jwHNCjm3bR4PgRuWTAxty1EyU9viEopm8t11BfwNpJhijeHsAoFtTC0



H6JZJmBV2rPJ66txbQs7XnYjhjLjRpgHdgWI+puoT2Uz5bZQyVuNMX8850H6D4Urw7ltcVL7



ZaI/UAuTk6xmfZKSZJzBc3qOSj+zHs5TkhVpM1B4OegcYi3bEPgfwHHwH8AE+L9Aw5od4Hw/



MGj5zoD3Ad/1ugriRjTNdEDU2PpNBREK+R+AzwNm0WZYvpu5moSrtCu2VFszf+epheSXjtG/



9QE+leWZYUA6HdjMfYyJjDkWN/4Z134X7AL3ABXR/QWvkvVn2cQLh9alI1ASxWJWMVVIqlJ0



Z9dpoCfMAWtfztR7t1dry8fiXGlt247K29NTqZAPs01dC3GZfquyI0Bj8Z8KvdzsBmeBytFQ



JnllfhvBc/Nj8Bnp2Qo+CSjt0vERlcigstjOugB2gCFwy0IjA7fsg3/xQ7+e/szXmscpId5Z



WqYez+zU+/aEcfz0noam9JCGK6Uonl2ox3+vlNTvzNbS+VKmW6JrcbRYCuIC61/nm5kEWKyF



j2F2d2DOfa7Ggqja2+M/t8HcqPYY1ygd4m9QJz8VhyudzD7fysD3ncyYPRKHJerppW0Uahdw



P4XwYsxD+FWgAP5T8OtAoTkCGsFSQ4VWOYg7rVZgoVOmKzCEzAX6GE7U65k7+UHS0jYLVj2t



PijUVLAi/FwlBbbumGCbktWF+Nd+FicNn0XBFZI8aTlFe+IKokbJUKRLtkgaMk9wz/BFYLxa



+38EVOSXqSb+KeNJ/z35/QIk+ypHNgEqMUmR2dGhvgMH+QNJspOde/dN1WrZH70yEjI4tz7D



jGaqZmlJ6bd3g3YgLaSpAt6Avw0q0z6gMqGc6XPySBgaR899p/G7cVRJxoBGx5JiLzgMyHfa



xvId06CS3LLQ0OJb9sEbP/SLy0vhz1/8xbD2sZ+d+xdDL25eXIkmKQbe7G7JrE/Mh8O4ND9K



CXKKcZESi6Zfbkui0ZWQbMG0yKhlcAfQ8kjEHurru8jQzLbW8K2ZWrZ5LUk640w8XUyyV/7w



914ura9VjyMsvXDkJZ7XUuGqp0IH2To9OdW3EB6EIT6GwwgsVkT8uVe49zGeWwf/GiyCKlAQ



VAhLCkOjiqCQeG56ZLZVHmn8TeQBD0TtR9lYjnfLKpRVDPPhuYpOEZdB8BmaYWAzziyNIkII



SYY06R+u/g7XtcwahAK/EZTKy+i/3/KbI0BD8QRQ4UyL94pAwZoCCu4Coo2y40E0tAzTaGed



+RQGoeUitan76GCrlsu5S5Vy3XSPg91AJVHwpTnkv64cKklDwElrakTe5KiQe++vCpY0vmea



DFuBSkEe02/6DWkujeWTymM+ND4aqvPglgSJcNvCUy/+S8rSZ6PPX/gifY25plo9s6USx8cn



Z7IPVuqZY8y+2IyCjFNRXugLeV1cbV7LxL2IXBfeQgawpm7uUsQyHycTXW3Z1jH6T1urtXqu



Ws/ROo1aUJB11lh1ryy2sXlljinw2UPwr4cGcSfvSHD6ABAmJDOTjb6JFWfxU7SH63y/SpEf



y/D/CRhkqoKiwGG9U0FUGAwyXYGUqQhwqgAqbw8W+SyDhou50IMCZOgUWFWQp4HPKgwqHWvC



IuLIYTUzrYXkwWfp6GJy5fSj2Vy5TPvkFdKIQEVY9gglSXrZ63yY65d413yokDPgGJiiBJjF



+4oe3Nd+bqgAACAASURBVA0qYAa08O636RThUzFe7fOsUt5KZ8bqWBLNUKJEd/EYm5HiFAPD



QlPPapL5OgAUZpX5+4VfmvQDhVyhNj0Gv2dQURpoKBMGKM236ZUPPeACsJQ3fuNpKIg0EhqU



hpL4rRHwn1JCbv//D1qw2xKo45O7G/JXsRcpnGXk+a1qqCEAac/JOFReaYOdKMH9zFRaam2r



7tvfE+od7WFRH1pXFkPv9Fxmgqb4eq0Lx9fL1d0MMh4qZOtnWQvOysGmvnq2vVKoddOdm0zT



W1WsZcaPRXmchNSKbhzKGB5ihnCTnjsZofhyLV7BQtXv5JrM/jqQMQaFWYyD9wEFE4FNg0ef



awiGSvIGuKNSTqsFw7UwrgWnpEjfk8kqSTNQUNhfN26Pa9mVKOnj+soncoxy12Knm6Q9SROQ



DH6lMjbM8+zqlArW25wbl0o3ChSc/Vu25d+cn403M3WfrmWHgmxTqSBJwnu/yznpW9rBrnD4



7y0S6dpeOr5eRCnfoqPrjpaW5PLqRs5UEksQld38WYo0gokhzjAAzK/ytBsozDc+x88bmZ2e



pxnhukZa3ktXade4zulfCF63pJRW5veWhNumIC0pXf9CHhXSBTAItIanoFYHDe9t5SjpDbnK



V9cy4ZHNbaFld3843VoMM8tNobfIQ23Zes/YAvuAzNTeA4nHtraGZydr9fuylTobyeBWOlln



TOQyzE0Y/2ieiOJt78Tl+Z38pmesswzvYBITWxDWepjbl89XnmIWx5/RmFYgOoChoQheM51a



NS2nxb/hCtgFZCRxpsxWARQcrbDB0sd4TgEVRaFeAn7b59hzPX8lSnoG62HsA5Q0ejxhDCQV



fL/pMwq6StAHFBTToeBYqimY58Cnx4bar9IYR/nLNMhXsfwM0G+kTYE2zaYhi6870lAnj5l+



2j1fpFdrjHbLprXVVNh5JKWBhsDS0TgMDSE2LTuA98yb3zdIM0sF7xtMn7TwPa/dGJfK0YhP



Onx/8PlGPFc5N/3m+ZaE26Ygpe/lUeKY6X0ApmWoc8YwNIPs59iEKVrFIzXO3ePdLe1hx+Zi



WLo0Hrbjp+oB/OPOHO4Ol2mtdjHm+ObKerzEvlL76suZPbhRjGsJA4pRlV7i6hbsJkROmL1b



g6G4fwgFJrTP5UNmgQ13mENLwJvbelyrxtVq9Sg/B4GMNFjsN5inxVNYZdYBQNslDQqBAuT9



hiD4noKhIhm8ryBRQqUWuZXjKlC4bRtcpccKd0CT9yIDxFN7mYjYjyO1sDySxq1C+Q2VRaur



8Pr7mhDlvsvlz/H7x3Kh71vVMLSPrbb/I0LfEG5upe9c5niIwXjaVVm+my00ta6+U68lhUo5



h3tTu9Ot+V2Pfx/n5sfSXUWQBipBF7BtZhXJ+6bDfJku6SD8fQIQZ3rd6pPPmc6GMenl3Ot+



VFpLE3+/c+03h/Reo6Tx900Pt01BbsiZQvgo0BI9e00OK7/5hXrlb/1v0fJaoadSr5QKLbn6



hze1xsX+jjDORvZ4FGXqBpXliaXQm20LS1u2huzScnVzdQ0HbqwqYh8NnGHncdqwuZJjSSJW



EkvlmnM3fF3jW5QP+EOvxhUZLWPZowpmbbgJVaBlRIM+MkyGCoVRobcKsRvcGEr8UCB8Rvje



FaBFVUgUBuM1eG71yhLJZ/GcyrtJbTtWn6rgGlPy1y5xHWVJBVFhVDAbQufRtFMCXFcgTmsY



l/D7DPR9oSk8eKGQ7cjWmp7rYP8VFdH0a7H9HobIfCe4UnL2fful+uqO/dVweYAZMc+jXNnW



cH/bQvjDfTyj0PqeMI49wO8Og6lr57s4NujVoF1D2H3HtHvUkJhGn1FpLgLppKKpQMahMi8B



6fP9wWsah1sSGhm6JR/7Kz6ipdkGtEIKDSHKoBxxZ3foX16a/RTk2g4nd86XwurpCRw4MCF8



86Ywurk7rB/sD2NnxsL+lanQNVePlqJ85p2txeLZqZX1RxlhXKxl49W4Sjs9nQ7FMKMOF1Me



ZbFYOerf2SH4rmArNArACDgKtGimSaY2QkNRZK6M9hnvK6wGBcJ4pKtMVChVJJ/rBOOgYckb



cWkgfN8G9YDrP6jmfIUOgkGuHQTd4Ag4B54GPm/8HhuC2BBcLqXhNWbnjK8lf7ijqf7EO+XV



dpRs6Tnu+E3fEYZF2mh7UA4GYnsWGMGHD/F4JQxhe/ILefo/eGYXMK9D4BRQuL8/DH3/hf+X



v03PCoC9qbJ//2v7uaDiaFz6gAq0G8iXWxIk9O0ODeYqCNeEEQcNoW/PyjxtCkaUEZrNlThz



YWqhuBJnm9cpDDKl8tQ2fG22/MwXwndGfifMjk6EAVz9nFmuJoeHq44au/qIBl3L/Cp7erJN



AN2ZRNTMHrRdvcnlsUstjyCrMD/VC63VjUFrJ0O00A0FUVgaQeFUqRrWvyFwMtx7Riozfddq



gnnT8hlH49kb4zMudryK6GbNfrm1tfB8vq26zNpxBaRBnx/l/OI1cEiFxji8rzKqiI2gy6Rn



amHmSCn8+XmEvmHlfVY0LDuCVuHdFUbO288zBLWVaScMIKoQheps+OOHeda4h4GK4XsG86jQ



ek8aKEfm2fyaP42AafPo9xq/fa6Rf2llfNuv3eeQKnCDLr6jcmg09wDfNR0zwGqqofHsxq+b



8NeP3u4gY6cBwuo0idyz0HCNpX93MrW7jTGxU2xQP88gXinKliejej7f0pqpLNeSpTWmx//C



vwrb4Mwyyw/XoqZmPLcvHWuB6cVQiFpDYWTt4abxg99Zyl6KK3Xme+toMxq9lA4sXMU3MwxY



3sl3J8GNQabKSJneYIIMa0C6aVUVFAW/IZxeszrVECSFR+H3GYXpxtAQKK2ngnA/n2IWc+0P



1qvszbOhsrQnwgAwfXeAvwn+OVAQLXn9zj6gED0PNoJLyuotWObKRL0wO5JU3BUhtbyN9Jk/



38W/Hs6748xaFAberIZvkc71IZIzXAnDrIhc+yHS5LdUhk1gL7BUbNDH72rNjd/nDNKrcd74



7X0h3Rr3jGMYaEiko/cbNOE0DcqFJYxKJA0ugVsafhAURII+A/aDQ8ilVpu5Q+zpnO7DlzAM



EtE3H09mcmujsqazvZZdTpouxvVy//xU8sjCaphtKrDdQWXxPna6vbq3OQyNLcb3N9Wz5cWv



zFTeIUKDkjq/qDHtA7jfpGuMkxaQhgIyWElXhDau/IWjjFVBPMpIhcNgY7KhIF5TKRrPKfgK



QkMIOL0uID6n0ljCvBccBf+en2u0jlQoheYqeBU0qmcoUfgEuAJMu99VcM8Dn1F42WTINJRw



UVp4b6g0tzOJ/o8YhjHNKshOICkMqmGOnr2rufCBObZ6RAAzWGgcKIWFT3LPtA2C04B710tU



5cbvK9SNIF3kpTD/5ttrwvybJ7+vwPue91VyYbp9zvT4/vcHaSFuefhBUBAJoxV6YyP30Vlo



9AjTPVg+mz/HwBoDdzXd6dSZpDWzp/zR+ff/5Nfzv/I/rpSO9OTGc7n6gbXW3Jubs7VCbj1p



X2TS3fxq+BDzKV47n7QhCEZ9Y6ANzAf8s3Gg4kXw9w3KIfMawVsKV4P5XpduDWsn8xvB97Sy



CFlaKioo3UAlbCiU8WkRve5zKth+oOBYx/cd41aIVKKTYAAYh/gR8MdgBPQBLavxqCCmUSFr



LTQl+1lOghFpYxnAlsXV8OoVrhu32AR8fyevMH0+vFlJfutuZPZhro1DsyNQpId7VjVNryXI



LsC1VDFMqyWQcXnftKrsHr0ufaSFR9NkqdoPFoHpbdDSeE2vtJCOplElMk6Dzxka39j4dQv/



moHbHRpEQDFsjCaPcoRxuR7WXX8VnwvzbEzYmyTF5pW1Q/me8IeZc1/8kXz0xTWkrJjpyq/N



Vcdqr6/3Zg4UMswzgoFM4BqNmca1rXMqOzjP/O/N/13mx6d/wWWt4Rd/vxr948/SlRU5mdFP



p9UPONHdkg/d7OhUYknKxFbSIfMbjOc0DTJKKAwKsfS7riAtrdSRVqOfYNDSuSGDRD/M/c1A



wdLy3wMUBgVs9hp2cTTOV4DVOuPWWjbOta4vAhXA9FjSPAIGgSWUpYjpEC7KopUV9uAXGK+M



tReQ02Pr4cq93CP+aB/58rsc046RhxkoGaaK1RqiS/8FveLkKZEHCG0yyjNCpb0KTLNpUoBN



039OkKaN/DVKSEuiG4PPNGTC69KmoYj+vqXhB0FBzLBEwHJpXbIwvX6IYv+uWpi7px7mqR93



d7rGKNTK+54Pj3XlRidwdPKZKiPn7v+9+ntt/yLzU9P/vFJowkV0UxjEXcmp0bX4/SsrTLso



dC5/fubfxz+dObjWFm1d+F/+blfp55MvL/1Ktpc1FtWmbPi/27u3GL2u6z7g33B4H5K6kBRv



IjkUJeouRbZsKbXlS90krWw0TZCmbYoCbQM0D00L1H0q0D70oQiaAkXQhwLpQ5uifWmR1mkf



FMeGLdWyZUWSLetCiaIozvBOiRIpiqJ4mVv/v8NvEUefhuSQ4nCGzizgP3ufffZl7bX/a+19



vvkuA+/nZ0PyMtOjeXFs4tSZfPNnHIQ+BYvVRi4bCZkaUlq8RkbPLM/76pf8m3zN0OMcLYUi



8uoAKf5pgFi/H7wf7A/sEMZRjnxEO31rIwpLdwU/CzjjniAO3Ow8B5Im8neeCvTD5zncQ2Nj



fnn67B35zG4caHxryrIbTCTwNMexB5M+FizOWxT2Rdc8meW7uzsTw5lpHGjiSO6J9HsDY3CK



ttCvTeL2vcnyjW7dNo5tUHLeft2Cy+m3+pi2dLY4SBklizSWhez8rL+z4uZ8Bvv+vNUqpJiX



fcA/D08sz9tQ+kaWnskPBAydXTp/ZMW6jZ0TPx78V59Z/2cL9ufHOl8O2//GvtHO/SP5FOGp



+fmmnGW39I+8O29kQb5OLg/7y08cWzD/P8y7/c4sb445o/nty5UJ15sGP+gMI+KZkc7h5UlF



aw5bJEVU0RuJ5R0jkJX9HBsaGR8fWbGgc9eL453X/ZLU3pAV0R4J/lawNnCNbLsD/WmPPPJs



gCxFGBFWufEQ8keBnUh91+sDfcnTE+lWBI8HS9N1vuZ0ST52uOh0/kPunK+OXYDQheMuHhsf



yyteR/PdGOOv55ozcEbO4eijf0dDY5IiOr0uR2p9tam+qn37Xt1vlwki5lhH1Gp3TdLZ4iDn



Jzu/syFHnAN5SBz1EJ0fz/FP8ixkZyyLe9euif68wWTJkrEVfTu3rh4YO7ticWfg0JHOX56/



cPzokfEVz84/+9GOhfPyn6+xhcsmVnzmtf5Nj52Z/+Hhib4zQ32j4yeWjnXeWZnP7d0RvsTg



owm0CzEw21Nfnu/zQ02dd9fkmOKokvdNNkcdC9omRjkIwoHdoJG++ae3nT778kN9ffPy0839



z+W/90O5gbQWl3P99yBHneZMX4uObMidnbMhgusiEScxRgjf/KPt2aTEfWS/NXgmoMPm4DeD



h4M400TeFtyXL/3uz9vn13z3HOcXDMbn8iww9mupY9d6Ici30I/55asDcVE7xnDAOejbJmrZ



IMXTKsZsjxV9G7vQ7ZrLrHOQ0fxKGSuMdo7ls9w+P700b08/OZhfEDve3//s7ctvONs3MDY+



/5abRk8ntCw6dLCzMt+HszBfG/1h//jZO27KISPnpr5DI4mwb7/waOftHy/PIXdt3pO4JC+k



JJvPGOVLobMGWYiBfFDq1pAzO9LEmbxqNpqXNsfX9/f3vRVuLIyDIAkiWzCRXQrKBwJlyN3I



yNl5987rLHwk/3ycNz4xlig89tnccMxC3p3BG4GdB/GbeSbVXt7OVf1LEUX/IiinjP7Ne6je



SWp87ZRzjm8Evx4MBoiUHcO3wHyUwNJ/PO8v+4109fK58omvJz0ccA5OdijzHEoamzTPRZ5p



9NsW+lxrMX/imc2OnbVr7FF2y+X0y6xzkMd/c7TzxP808Q+P3nDz/BeOHz3zaHjjZ20PLV3w



4eO33ZS3lSzrHDn2YX5e6YPOtv4lncWLF+SD5ONj+xedGt12Nl/4sCjbzcm+03dlp9ic54oQ



HMeXbQ8vTyUY50iUHw3onNoUDiaKvv5A+JAj0fjA6EQ+mt45u3N0dMLRQuQuQVQirbydAZmQ



tZH8zyaO0JcHfdw9eyB/7g1uDizwEwFCcoRaZOPcETweID5nKDJWSnnlHESZ3YhTGJcO3ww2



Bvp1hHP/lsx5Q2rvytd+/d68sVODEyPjj2XYL6uTo99LST8I6Mhp9wX6pCdi1tjJNlJkreur



kdYY+q7+2bZ9be4CyrsBqXrnrq7B31rsazDU1Ib4g/+BXLFE3nf9zX83emDJ8rNP9/Wd2ZdP



2fUtPzPvyfff66x872y+gT27wo0DnWMbV3eezP8NdpzMtw30TywYXT22/Hunwvf8oGEcYSyE



Gd8RhATjIedIHOLE0tj7l8LVRPejD2ev2ZLvab4x3zp6cv6ikzvmLxjJsw6P8ppX4wwWxULV



giI3MiZKN6/u1KItzcksBJuXM/3Ej9J6qFsn4zWfbX8+qXaCkv4ccTYHvxNwEs89FbmNVbBG



CwJOov1dwYZA3XsyzueTLkt6Ju8P8ezDWR7Mh7Pe7JtY83I2zg/yP6T1uf+NfD5kZ/Bc7nNG



OxpHkXIshjc386k5tfMpvqqib+OxhbmTGr94eVPKVgVvuhkpvc5dXYO/s24H2RZa/It/39CT



sUTDQ8FdH3ZG7zkz0b990fvz/6Svb/SBO2/tHF20vHP6eN7m/vbbS176IL9hePPCswMfnunc



lg9O5GO0zT/DDqZtovTY8/GXzck78gwE5i0qvZklsQtk+x47lM+iIG2I2PybxGKoV4tiR7HN



08uugKy1cMkuCXH9Bqf3HI77NCBCOz+r/0ogYnMWc0L+7Fydvxv8QmCc14Mcy5qImeS8GB9h



tPlicGfwvwMk/1o+5755bGz+TfPm5fPz8/wc3II9ExPLfphfRxiOD24dO3nyD0fPvcjxf3OU



MlfOsC/YE7CtXc0Y+i9p56tsulJz5/D3BJx+b3A4IIIQ3c5FTSXXWCg36yTvQWqLo0U+x9HZ



kTA6vqkz8OyeE8cHPtzbGb9tTeedHfv7Nhw9O7FuTd6pm68O2ju8YOQvfZj3XeVLCnK6aj4I



9WraIzLCfj9A7M2BqOWIkuNIQ9CtSV8IjgZ1nEm2iXBILtJxEiTjIOsSlbdnp+vKqMidD10t



eD3vArDQyGzROeRg8NWArAuM/1A37wiBsN8JtHMt1bNxOQfHpOuvBMMBPX89ODI2tvi/5acS



Do6PHftqXpiIiW56Mi9uLMt7qj4bs+WtK+Pb05XjE7CssTjGewFnrRlwispXmqJpFXOjg/Vh



/xuDbQHhJHYPDj1jMisd5D/924/ZQ9SNIfuGFnX686VwH23LWyc+Onh84cGbz4zkd28G9qya



f+LBsHxFfnRvUT5Duqo/rw9nqfPWiSby7E57xLYQQ8HGIM8iDfmc40cCW7lob5FEVMQs2yCO



hSTI656Fm0j0PuhN9F3ZnFfebs/xKuQb4wQW2riObPd1r7U1DueUFyGPB/8xQAjOpNx47ZS+



fydYH/xecGfwpeBQX59XoE5Fr4ntnb58+rBzZGu+D2x5/7zRfAPY+PHoxxHKMYzh+qPA3In5



EU7RdpKmcBr/1FhSuuQo3AibKBOkNgdPBTMmRYIZU6A7MIOU9EYvOi7LByV2H8sbi7IvIFui



+OkbXj/dd3igc+qX870ld+4P0U7EzvngbiKO54/GOX56rm5D/CpDvh8FW7r37AiIicz3BisD



pKZTIdnzpHX/wWDn+vWdo/kN9ea/c/P6lm/IP9zyI55n18Zx/DqWz4sPpR6n4jCcUH9SuwF9



Xgn+a/BiQAf3yxmTbZyEc3w2+EbwBwGy/+uAvvlfy0g0yIfCRN+8HSBpvtAlPxYUb02q7cEg



5mmOlI6QAgIxFqlUvtf2yqZLaiwpHUBegCKCFX3t6DMms8VByliTGaI/hQjlHLopFZ9JujrY



ljPUvR/0jdwd2zo+5PPnzdEEuZFve75m67UznXzJw7ndQPRM3fNbtjFFLjuLI4xrY3w50J8F



QzywT4jo6m8JHg1+P87R7B/z+xfnCx76c5yaGEr5Tg6S/yvkfznNc4f+HcnuCh4J3grUGw6+



Fxjb0aLpK6lxSZo3BBlM+rvB0wHH/keBOe0ODgRvBHYEZexEz5jmfHv28PxDD31W/8meF+Wz



RdibPtsCR68Z1W02OIitVORGknWBhUQEi09ERYRFoBuCnwW14KfzL4/hWDDfa+UHdyY4AbJo



Oxzn2JhU/0cCxxIO8E5AFgS9ZNH23e69JI1zqANFsH/QzXPURvLe8odTNQTtfyk+dCxfMXEs



73HKc0Ez7olUovuzgei4JXgqeC6gm3nXOiCDuhzxZMCpOMdrwR8Hfz+wm3AOu8JwQF9OZrcw



Jw6iH6l+7BjypOZy7upcvRklYCnSSul6SyAwOg7OqFBiusWiLAwsnnRxsCbYFtwWiOpIgxCI



wgk2BxYWodQRBZGAswwHBCH25MdyfIv77gTMfGV/s3Mwqn70uyxAOES0q3CcElGdw+hH1CLq



sokxjU3nuofoDwS/HfxR8IOgM7Bg3cZ8bPefxEGj/8jBcDG/1d7ZAaHpvlThkMaGV4KVwe8E



DwbmrNzc6CIte30t+X8YcI6nAtcbgkNBxmmi646k9EcqbTmxtGA+HECfhWvlEMa7lJQu0tJT



mwScxi5vuZhJqch1OTqYeE2st93yFCwK9NsfIOaqQLkyhJMiGyKL7LsDJEEWcn8wGKwNRFD1



REmkfTtAgpsChPow3+CuHX2QUTR2zHCtrp3HWIiCNATh3VdWkdV1zYtj1LWyKjeX3wro+0dB



IydHjv1quvHu3ZB2jJ55mTXHqHz1Z944efZs/iFTVZPS5w8DpP+N4J8FSPDngV2RQ5uneQsU



Pw3Y5gsBXdXlcOZmvuZWOiZ7fiz5ttR8Spf2vcvNG+9iUvZSh60JW08m7uMErlgfO97qwPPY



K8GMy5U4CCOb0PrAgprgwi7sDuUcNenDKTsQIDRy2xkYAiZbMOQR3bVDChESeTYGQwFh2CK8



a4ui7tEuknxCamGNyYml7T5KF4vJ6YyhjZQOcYTm2eOfJ0V08ouZ1ueS5ttSGuLuTX4o4NTl



HDUu/Yx3LHgy2BmkffNc8ktJOSD7sZP2HIBzLA3sGoIJmyhTh3OU0N040gvJxe5dqE1v+WRj



TKVfQWttgC/6MAeBqLiyPHnBxfwGA/OzlmzPbjMmV+IgtvmvByZjUhyBWPjdgYkjAge42OQY



CkrkGRtB9wfG0adxEFo5ohKG039J9VOLVX2pR9rldNKfOpyVVH352nXWJ4+o2j4U/Hbww+A/



B2Rz8NcDEd2Rh85vBYIBByP6rb6lxJgcnh7qvRysDm4KBBpr4t6NQRFlT/J0AQEJ4dQh1f+5



q8n/1thlh6o1lbZVV6q9NtWOrhybPeklxQe6qeMaFziAusUJ/ajzUYAv1sncBYNVwU8CUnM8



dzUDfyl9OaL+XwkQATFEgr1BrzAOKYKeu7rwXwarxdNmdzAYMK6+kJWjlDEZHsnaor22mwP1



RWCYTGrhkFX/2pbO8ogr5ZBfCL4Z0OVfBhz1nuBvB4sD898V0PlQILK3F7a3b9eIwnb6V9/u



gPQIgmiIc3NAhgJHKs5CB/VuCHpFvxeS0sEc27rVnC/UbrJyfbHfukB7cwE2s0NsCgSZDYHA



wT5Sc5pMx3Koo7nPOQhuzQq5XAd5OFqb8JNd7RFFdLDIFzL2ZEbpNp80QXIG16e2IqvFEJmR



BCndPxOQWvS1yX8+sKuJtK4tFEcq3UoXJCyiuKe87iXbLND9Sf9e8KuBe78b7Ax+JRAkkIQt



lL0RcA76Vb/JNuP29t0ej4OYB33pZD0QRj+DAWcQjDhGibmzQc2pyqW9ZTUWnWp+xkBkdild



jUmqTqXnSj/5l877u8UCRvXP3vS1G9j91TGXEvqUTlLt6KK+4PfV4M1g1ghjTVVErXXBD1sN



ROjNwautMtkywqUM3dOsaVeLJqquDFwjowhESmdEMQ4Qzro1oIsIdFeg3WTCCS8k+udkS4Pf



Cjjqfwks9D8OzFfZcDAUWNDDAbK351s2SPF56S2ra3MBQjdz1p/gg4Ck6rp2rGmTuu6V7dRv



y0AurB/9zGt9YFdCSuMgc1v0N5lUuX7aTqu8dDAP62ZHYbP2vVw2Oiijq7mqSx4LzOu6c5Ca



OMIxKvKUlBFWpUC5CTNemyi5nLJoZzzC0K6dxUVXpCeI4bqIU6SwGBbNjoPk7Tq5bKTmom2N



0711Pqn+/ldK1gT60vc3Agu4K6CLY8NwcCjgvNrp80L95tbH7FK6KJ+sTfXVe4/uNZa2bXvT



jzMAvdVjr5GAPeXtHI4zHEXfywIO4571NDcB4EJS+lTarqeMPmwvJe16lacX518b2A2Nz1G/



FdS6JjvzwohTFdsgw9XEK9IxtijAQcoAVSdFVyzO6BsDfTpq6NOYFlQ0RALC2MZH0pcDBldn



b2DLL9FPW692vreOuoj0RMBBNwQHAotqt9gXvBeYu3H1VXNP9mPjuJ5MJmujj+rH2tgBEbst



yOce0pcICrcGg4FyfWj7k+BIoMyxqC3tXeO+3EBMcxMU9KUPbZSVDvqZzG4pbkSbui9P6rry



yjmjceQ5CR1/Gsw6uRwHsTBlqJq8CTFArxGUX6noS/8IKsrtD5D0oYDYxSzuI4G6IjjnfCu4



JUBeTlO6JtvUa+ts3uqQGk/azrtnRxoKOIf2HJVDGMM9Y1Sb6t/1VOVidRHc/ItAFVmNQ3dt



BYbbAmSzyz0TCGKIzD73BE8GdBVcarzqQ6qMTfVpBzFXBDa3TcGXArulgFDOUnNN0cek3T99



SmqcGpe+xrBzWOdZ6RzRq4lE0otJTRqpGLqkypVZPAvavl/1Pk3KKS3aU4EF2hx4DrJDDAWc



VuVN1gAAEFRJREFUooxvV0EWejG6thbBzsehoEhCT/dKai6u23lE43zlbMYFOhFjF7ST/zTS



HtvzwfPBzYEdQiCwI7I1Mt8ZsLk5PRe8E7Tl2Vwg9y8H3w84trraLg9uDd4MzJFNFwf6b+80



u3LtPlsKVGxWNkz2E0J/Tq2eEwCp9ZEam6wO7g043J8Hs1ZMdipSk2SstihHFuWiWXuBc/mp



Rf9IULIvmVpAC9HWf32u7TSfDzYG2iK2+nYWxLZAoteG4FK6ag/amB+IiqVP3ZdOhyAlZ0BS



ERyJEa/mY25PB98Nep0jRY38IH8Fiy8G7V2znOTRlP9i4KgoAH05+ErAIUv2JCOgCED0uZSw



B9uqW3ltyjnuS97uZk7/L5jVwmiXkpqkCVq0EuWEMcDiXQ3Rr7FEfiQwJlIQ9xBdBHTPQykH



RVpzGerCMaN2MxGY0yDYocC9U0Hpn+zHRLn5kN450YtTVtuqpy7pvT5Xenl/q2/zMa+BwFw5



qCOe+UrNteaY7AWFk9hFvhb8OOAw5vVmYD4CmzHsWLsCQeZzgR3lpWBPYA28EGNXuNQc6UR3



fRqrLV/MxQPB8120783K/FQcpBS3cL31y1iiBWN/Wily6EfURwqEtHjEOPsDi6DM+Ei0Iahz



7avJF3FuS/7uABlESM5i50Gwj4JLCWK0dZJXZtx2eS6vmpRN2fPW4GhgTEQ2Jkdnk88Enh1E



4kvJ06nwleDLwd4A2aXs4ljFhuxi5+CAbwRsvTq4NzAm+zkSuU8PKF2TbUSZNWN/+pYzWhvO



YRf6drA7uC6kl/AXU5ox2vV7jVPXkxnuYv227+nD4hPGtBi9/R5I2drADrMpOBOoK/KJjBzL



4pfDDCdv8YmFHw0QgZ6TSY0nnawOAkxWPllfV1JWNtjZGsd4mwM7H5v8SSDCPxZ8PzgSXEy0



+9MA4bcE2jrq2I23B2wIxwI2ZB87AOe0474UDAbaGZ8+ZafKt1NBbDC4I9gS3BZw5CeCCnbJ



zn5pE/5S2jJykbeXPIxzNUQ/IicR5RjT+br6N77o9JNAhLIAjg0VRUXCWgCLvz5wDBOxDgWE



YyG5hZ5MjNU7v3a90qVdNh35GkfKJqL3uuCF7rV5vhU4snwvmIpwpHImu9O24K8FCM1GbMK+



73aR5LxwFI5jx7G7lH7lKLVuytmc7emmX44haF13cjkOwkAitTaicNtAiNu+zuWkok4ZtCq0



y8rIiOBYAaJaEVZqLARHeDuDiOfh2fUXunnPKHYZfe8KNgQWFzlWBBbQfCaT0k9qntdayh7S



ttCXPdjowcARUdCq3THZKYl+gVMAR9kYfC1A/j0BRymUDRyX2LSk7FTXUvrdH2wNDgTfCjg2



MeZkbZqbs/XPVBykJrUzk3g8ENlNusqT/YQwxoWkDFXtK636iHx3IErt66ZJPuGA+rEbcBiC



/Hu6OJ4UkTi0XUU/wLEcxcyBU2nbO36KzgtytO8bs79bJj8dUuNVagx6cmwklSK0udKv5p/s



lES/7b7LURyfBKbbAwHGDmU8O4q1MJZxOcnRQDknNb76nEN7db8d9Aag9pi5fX3IVBykZnIm



GYZhoIoKJi2CIerbQUnbGO183TeuBUE2BNYemfW1unv9ctLqExl7+3Fd0S3ZZmEq6nEODmGn



4BADgcXWD+eoeU/Wb5VVmurnRb+crGSyOnXvaqZIeHPA7ojrCDQcOCK9F1wNETCGutDfLYFj



knWyPsTcrY95K6v5swu8E7zYzSe5/qWIMtWZbE/FrwS7AgtFkJCxRJMyWLKNlCE5AfLbHTYF



6nM4948FewMkEJVeCcihoCJk2znaY8hDiXr6KeEkRWo6WGD1RbkLSY0lrXy7rv5rzMnut+te



jbyx2OFg8Ejw3eDPgl8IBJWngukQZIeLibWnWztoXKz+dXfvch1E5LJ1WqjvBwiC+GVIxF/W



LUNIxwFRyPYrQmm7O+BMrgcDker5oHaLZD8mCF7SJn+VFVnrulJ1ndE5c1s49spuwWQE159y



aW/fdV3pZO27XV+1xBjm8lYgmv/NgK3Y9EdB2z65vKpS85ysU3qxL2nXuxY2OTfqNfh7uQ5C



JY7xleDxQJRHNulgwFnsEhaUE9gdng2Q0kKKNG0DMqxI+FCwt3VPHfe00Rfog1MR16S3r95I



1l64qs+JOW9b1Ovty3Xp3K5r7NKvXT7debq8EngIdmz8ViB6T6e0bXKxcaZa72J9zMp7ngEu



VyzU7uD24L7AGbgI5xnlxcBRTB2Ow1Es5GTHGhFoR/DZ4IHADsXYdh7RksOBrdyDILhfjsI5



OY6jGdkQ6KN3rLajcBD9vR/0SjmlMdS5N+B0nl+IgEI3jj/dpGjrnOEaWZu/bEw4yeEmN/dn



2ixwJTtIKfOnySBRbbNVfiXpqjTyvOC5xMK/FvQKYrrHKRzbEKUiKOK4h1RbAg7DOcuR2mTm



PEgvOMi378nr34OovunERhxlf8AZtbGLSI3Xbp/LqyrlJIISuSF4M+CgjwV0OhLMyTRZ4NM4



iMUr56hjBzUvlzCeWejhTH1nsDcg+iwxligOdgC7inZ2DKR5JxBN6WM3s/sMBpygdjFOgdSI



rxwqrz8O6Hh4Ing74Kx2P8Jh1gUIqVz/nKUInOynkuqnbFfX5RhsQb+BwNjma57K5hwkRpgu



+TQOUotJt1rIK9ETUR2LDgRDwfsBglT/8vqXgt0BENkuop6douojMEfSj/mtCew4yo4H6gGH



VHdjcF+wMxCdOQ1HIuX4SMgROaV7dk4OciViDoQOlXddeXOtuXACY9bYO5LntGxmpzOHOZlG



C3waB7kaalngrwfDwYtBCbIUgSp1r/JSRK0Ir36RudqWIw3lHuEooJ4o7NnJ/JHvqWAwQDxO



ow4xDnG9J7gt4BhXSszSLV00ov8aQ4FxHBfppdxuCYeD3UEd/8yN81ypHmk6J1OxwEw7iOi4



KTgW3B+I+vsCUZQgSZusRSZHDWSrY45yUFbSm3dsAmMOBnVfu20Bx+Asjmk1TrJNPfoY03ju



O9pcTPQ9WR/tMu05JKd1xHMP6FFHv0Pdaza6JTC2o6Kdk81WBXMyjRawQDMpyPByIKLfFyCK



CGp3OBkUaYpYjjaiuGcFkfWeQBStY4d2Vbccq8jqWt6YUkA2zxdSzolwiKefqpNs0+ftSTkI



Z+FkSKpOr1SZtHSRGr92hHXJbwzMA+kd/czBsZEeUsFLHa/cvRuoxyYc6tGAnnaSvcGcTJMF



ZtpBTMvC2zV2BzcHHARRRc3TAaI5TijfEHhARQok4jCIqi6ymQ8SIg4iE8QkRdYirnFF6s3d



e+5ri4wcRDt9KOdE+qeH3cPzjPH1BUSqjfoF1zcG9FwZrA/0w9H2B8bSD6c1NmfnABxInQOB



cruX9p8L6PaDgG6bg7e6+SRzcrUtUIt7tfv9NP0h00OBKI0YQwEiI5PnBgSjN4cZDF4NkIQM



BgjFsZBUlEU0gqxtQTCE3Bog/pFuylmNR+iAsHY2Y4jyZTOpMYh8OaS8NvqWl3JcjmwOJXYI



pHePbq45tnqrAk6pnA3ssNqaqzr3BnbPPcFzwZxMkwUs4GwVxHgkQOAdAUe5M9gbID3iqYNk



ovpw8FpAOJF7nAX5jwcedNskzmVDcI52Q4CgUjuUemwjWpMjgeNNiXvAQcpJapfhXBzUfSmn



LrklGbrq37EO1DO2wKCPcnD9uG/u+iGbAsHjVPB6wJnnZBotYHFmo4icReZf6+afTorszuSI



czBwNCGOLpuDjcGuAHmQiDjicBZRGdFF6CIwcovgSMvhRGdlxpdyCmMRY6unPmcrHRF6Q0BE



eeXG1s64dGNn145m+uUMyuxQ1dazBxhT/+oRu8eWwI6h7KWgdkx9VL1k5+RqW4CBZ7uIrl8N



HJdeCBBQpEc8hBbx7RCE89wXDAZvBgeCQwFB8DsDhHolQHT5csRkJxUkBo5m7JsCDsjROMDm



QB+cjz6cSF07wIng7aDam4v7dj3iXjm6XbFEHWNpd183/U5S/ddukuycTLcFrgcHYQOE+VIg



uj4T1M6hXAQWnUVtDkHM64HAkYZjIe+e4LHgaLA/KKfqtUFFZC8YcEQ7hP61QVBOWI7GEZQb



G6GJseip3tpAH3Yn/RA6atNLdLpyYv2o63jHae4P9gYcfk6usQV6yXGNh7+s4ZDmkcBRyYNp



OUOyjQMhNIIhM0KJ4GQw8KqQaD0/cJ8TOLrYfTgMO5RjIKoIzxngYICspOotTX5bwBk4hz4Q



+67AWPoyDrivnn5Kqh9jcTL9G0s7zsWpydbADvJ/XMzJtbeAhbreRPQWVYeD7QECcg5zcaRB



7tUBojnLS8mm4NbgGRcRjia6cxREduTSh+cEfUqVK4M6ig10y7W7O0Bwjuk+J3wv4JzGlS/h



nMC57CzELmYnMY7x2qL/vxr8JNjXvjGXv3YWsPDXoyD3I4HIOxzYTURuREJuRxrPCmsCRBWR



pYOBYwviOqaJ+ohY5GcP5XWdbCPqLe9iU9KFgf72dFPOJfrru3aiZM+/MibPGTmXdocCY9Su



kex5R9QezM8cvh3MyQxZ4Hp1kDLX7ck46ojAiCcibw9KzG91YIfhOBxqsJs/nBTq+JTsx8TO



gNCEA3AKjjIUGO9CYgdbEnAAjgqEU9BRH+WA9INyKqnrBwO70xOBOc3JDFnAYvw8yF2ZhGML



h3kj+HFQzyDJNoLsIrIdAvk3BIsCBNwdIOeKoGwiunMehOZc7wZtUY8z6BPh1VPfuHXtyGf3



Kqm+67rSchCO+HCwMfhuMOccMcJMyoUWbCZ1upyxS38EQ1DE+lLwfvBqcDCooxTSlngWsCM4



Nq0K7DD64ghVz3GJk+jXPeR1r51Xx65AykE4RfWhXDtCR9C+HKLSFDVHsIeT2n2+E9TY7b5S



PCfX0gIW6+dNEHVL8EDgwXc4eCsg7pFe0nkOYQtHp7YTqN8mcS6belKivl2jV9p2befV01+7



zzW5tptxbrvND4Ne/VI0JzNhgd7FmwkdpnNMZ3nE80rRm8GeoMTcoZewdX+qaTmdfqq/3rZt



h1D/hmBrN9XGc8qOYCiYk1lkAYvz8y6OU/cGXuL1fPBicCQo0l7KBkX6StP0E1J9VJ8qtPOO



c56B6LAlsPM4BjqO7e/mk8zJbLNALexs0+tq6dMmtbdt3BbcHnjg3hn4v0URuWzRbpPbF5Sq



X+0rrQZeAPAA7/lmU+D/H/4xuTfw7OKfiyVTHbPqz6XXyAK1yNdouFkxjIfg+wPRnIN41ate



oarjUorOO448KRL32oxjlHN4IPc8sSrwAgAHsUuUM9o5qm6yczLbLdC72LNd36upnyOPZ5SV



gWj+WnAsKGGbsk8vqdvXjnD+1zIY2CU4GUfwCtquYO6BO0a4XqUIcL3qfzX09iqSB2YpUr8e



iPptJ8jlebFLeKh2ZNsSrAu8COB/FrAnOBXMyc+BBf6iO4hoXxHes8LdgaOXB+f3Ai/hchR2



Utdu4djkCKWcQx0IOBSUqOv+hZys6s2ls9wCf9EdZLLl4SheGvbfdg/aowEngnr1yTMLh7Bz



zMmcBeYsMGeBOQvMWWDOAnMWmLPAnAXmLDB1C/x/Ifx30R2UxOcAAAAASUVORK5CYII=



", extent = {{-100.0, -100.0}, {100.0, 100.0}})}), Diagram(coordinateSystem(extent = {{-148.5, -150.0}, {148.5, 150.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end Engine;
    annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Components -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Active Damping: Components</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This package contains custom components used in the <a href=\"modelica://ActiveDamping.InteractiveActiveDampingModel\">main model</a>.
</p><ul></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Components --></html>", revisions = ""), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end Components;

  model InteractiveActiveDampingModel "Model that explores how to minimize vibrations in a diesel engine using a tuned mass damper."
    extends Modelica.Icons.Example;
    Modelica.Mechanics.Translational.Components.Fixed fixed annotation(Placement(visible = true, transformation(origin = {-0.0, -50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Mechanics.Translational.Components.Spring s(c = c) annotation(Placement(visible = true, transformation(origin = {0.0, -35.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Modelica.Mechanics.Translational.Components.SpringDamper sd(v_rel.stateSelect = StateSelect.avoid, c = c1, d = d, s_rel.fixed = true, v_rel.fixed = true) annotation(Placement(visible = true, transformation(origin = {-0.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Modelica.Mechanics.Translational.Components.Mass m1(s.stateSelect = StateSelect.always, m = m, s.fixed = true, v.fixed = true) annotation(Placement(visible = true, transformation(origin = {0, 70}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    Components.Engine engine(engineMass = engineMass) annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-17.5, -17.5}, {17.5, 17.5}}, rotation = 0)));
    parameter Modelica.SIunits.Mass engineMass = 1 "Mass of the sliding mass (engine.mass.m)";
    parameter Modelica.SIunits.TranslationalSpringConstant c = 1 "Spring constant (s.c)";
    parameter Modelica.SIunits.TranslationalSpringConstant c1 = 1 "Spring constant (sd.c)";
    parameter Modelica.SIunits.TranslationalDampingConstant d = 1 "Damping constant (sd.d)";
    parameter Modelica.SIunits.Mass m = 1 "Mass of the sliding mass (m2.m)";
  equation
    connect(a, engine.a) annotation(Line(visible = true, origin = {-35.5, 0}, points = {{-14.5, 0}, {14.5, 0}}, color = {0, 36, 164}));
    connect(fixed.flange, s.flange_a) annotation(Line(visible = true, origin = {0, -47.5}, points = {{0, -2.5}, {0, 2.5}}, color = {0, 127, 0}));
    connect(s.flange_b, engine.flange_a1) annotation(Line(visible = true, origin = {0, -22.125}, points = {{0, -2.875}, {0, 2.875}}, color = {0, 127, 0}));
    connect(sd.flange_b, m1.flange_a) annotation(Line(visible = true, origin = {0, 55}, points = {{0, -5}, {0, 5}}, color = {0, 127, 0}));
    connect(engine.flange_b1, sd.flange_a) annotation(Line(visible = true, origin = {0, 24.625}, points = {{0, -5.375}, {0, 5.375}}, color = {0, 127, 0}));
  protected
    Modelica.Blocks.Interfaces.RealInput a "Disturbance force on the engine" annotation(Placement(visible = true, transformation(origin = {-50, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-70.0, -50.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)), Dialog(group = "Variables"));
    annotation(__Wolfram(PlotSet(plots = {Plot(name = "Engine and Mass Displacement", identifier = "b7ca3", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = engine.mass.s, legend = "Engine Displacement"), Curve(x = time, y = m1.s, legend = "Mass Displacement")})}), Plot(name = "Engine and Mass Velocity", identifier = "96ebb", subPlots = {SubPlot(curves = {Curve(x = time, y = engine.mass.v, legend = "Engine Velocity"), Curve(x = time, y = m1.v, legend = "Mass Velocity")})}), Plot(name = "Engine and Mass Acceleration", identifier = "39861", subPlots = {SubPlot(curves = {Curve(x = time, y = engine.mass.a, legend = "Engine Acceleration"), Curve(x = time, y = m1.a, legend = "Mass Acceleration")})}), Plot(name = "Energy Dissipation from Damper", identifier = "cacc5", subPlots = {SubPlot(curves = {Curve(x = time, y = sd.lossPower, legend = "Energy Loss")})}), Plot(name = "Engine Displacement", identifier = "0db5c", subPlots = {SubPlot(curves = {Curve(x = time, y = engine.mass.s, legend = "Engine Displacement")})})})), Documentation(info = "<html><!--WSMINSERTIONTAGSTART ExampleModel -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Active Damping: Control Diesel Engine Vibrations</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_EquationAnalysis').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Equation Analysis</a></td></tr><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_SimulationAnalysis').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Simulation Analysis</a></td><td></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
This model explores how to minimize vibrations in a diesel engine using a tuned mass damper.
</p><p class=\"\">
In order to get the full experience of this example, you need the following:
</p><ul><li>A desktop Wolfram Language product; a free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></li><li>The <a href=\"ActiveDamping.nb\">ActiveDamping.nb</a> notebook that came in the same bundle as this model</li></ul><div class=\"mathematicapointerwrapper\">
   <div class=\"mathematicapointertop\">&nbsp;</div>
   <div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"ActiveDamping.nb\">ActiveDamping.nb</a>.
</p></div>
   </div><a id=\"headerTag_EquationAnalysis\" class=\"target\">&nbsp;</a>
    <h2>Equation Analysis</h2>
    <p class=\"\">
Using the Wolfram Language, create an interactive <a href=\"http://reference.wolfram.com/language/ref/Manipulate.html\"><span class=\"mr\">Manipulate</span></a> analyzing the vibrations of a diesel engine for different damping parameters.
</p><p class=\"\">
<img src=\"modelica://ActiveDamping/DocumentationFiles/InteractiveManipulate.png\" alt=\"InteractiveManipulate\"/>
</p><a id=\"headerTag_SimulationAnalysis\" class=\"target\">&nbsp;</a>
    <h2>Simulation Analysis</h2>
    <p class=\"\">
Simulate the vibrating engine with different damping mass and spring-damper parameters. The Wolfram Language makes it easy to do such simulations in parallel.
</p><p class=\"\">
<img src=\"modelica://ActiveDamping/DocumentationFiles/VibrationSimulations.png\" alt=\"VibrationSimulations\"/>
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND ExampleModel --></html>", revisions = ""), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5}), graphics), experiment(StartTime = 0.0, StopTime = 80));
  end InteractiveActiveDampingModel;
  annotation(__Wolfram(openClass = ActiveDamping.InteractiveActiveDampingModel, useDocumentationTemplate = false), preferredView = "info", Documentation(info = "<html><!--WSMINSERTIONTAGSTART ActiveDampingPackage -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Active Damping: Control Diesel Engine Vibrations</h1><p class=\"\">
In order to get the full experience of this example, you need the following:
</p><ul><li>A desktop Wolfram Language product; a free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></li><li>The <a href=\"ActiveDamping.nb\">ActiveDamping.nb</a> notebook that came in the same bundle as this model</li></ul><div class=\"mathematicapointerwrapper\">
   <div class=\"mathematicapointertop\">&nbsp;</div>
   <div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"ActiveDamping.nb\">ActiveDamping.nb</a>.
</p></div>
   </div><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This package contains a model of a mechanical active damping system.
</p><ul><li><a href=\"modelica://ActiveDamping.InteractiveActiveDampingModel#diagram\">InteractiveActiveDampingModel</a>: the main model. (<a href=\"modelica://ActiveDamping.InteractiveActiveDampingModel\">show documentation</a>)</li><li><a href=\"modelica://ActiveDamping.Components#info\">Components</a>: a package containing custom components used in the main model.</li></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND ActiveDampingPackage --></html>", revisions = ""), uses(Modelica(version = "3.2.3")), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}));
end ActiveDamping;